@@ -395,22 +395,25 @@ class CGATS(dict):
 		result = []
 		data = None
 		if self.type == 'SAMPLE':
-			result += [' '.join([str(self[item]) for item in 
-						self.parent.parent['DATA_FORMAT'].values()])]
+			result.append(' '.join(rpad(self[item], 
+										self.parent.vmaxlen + 
+										(1 if self[item] < 0 else 0))
+								   for item in 
+								   self.parent.parent['DATA_FORMAT'].values()))
 		elif self.type == 'DATA':
 			data = self
 		elif self.type == 'DATA_FORMAT':
-			result += [' '.join(self.values())]
+			result.append(' '.join(self.values()))
 		else:
 			if self.datetime:
-				result += [self.datetime]
+				result.append(self.datetime)
 			if self.type == 'SECTION':
-				result += ['BEGIN_' + self.key]
+				result.append('BEGIN_' + self.key)
 			elif self.parent and self.parent.type == 'ROOT':
-				result += [self.type.ljust(7)]	# Make sure CGATS file 
+				result.append(self.type.ljust(7))	# Make sure CGATS file 
 												# identifiers are always 
 												# a minimum of 7 characters
-				result += ['']
+				result.append('')
 			for key in self:
 				value = self[key]
 				if key == 'DATA':
@@ -418,44 +421,44 @@ class CGATS(dict):
 				elif type(value) in (float, int, str, unicode):
 					if key not in ('NUMBER_OF_FIELDS', 'NUMBER_OF_SETS'):
 						if type(key) == int:
-							result += [str(value)]
+							result.append(str(value))
 						else:
 							if 'KEYWORDS' in self and \
 								key in self['KEYWORDS'].values():
-								result += ['KEYWORD "%s"' % key]
-								result += ['%s "%s"' % (key, value)]
+								result.append('KEYWORD "%s"' % key)
+								result.append('%s "%s"' % (key, value))
 							elif type(value) in (int, float):
-								result += ['%s %s' % (key, value)]
+								result.append('%s %s' % (key, value))
 							else:
-								result += ['%s "%s"' % (key, value)]
+								result.append('%s "%s"' % (key, value))
 				elif key not in ('DATA_FORMAT', 'KEYWORDS'):
 					if (value.type == 'SECTION' and result[-1:] and 
 						result[-1:][0][-1] != '\n'):
-						result += ['']
-					result += [str(value)]
+						result.append('')
+					result.append(str(value))
 			if self.type == 'SECTION':
-				result += ['END_' + self.key]
+				result.append('END_' + self.key)
 			if self.type == 'SECTION' or data:
-				result += ['']
+				result.append('')
 		if data and data.parent['DATA_FORMAT']:
 			if 'KEYWORDS' in data.parent:
 				for item in data.parent['DATA_FORMAT'].values():
 					if item in data.parent['KEYWORDS'].values():
-						result += ['KEYWORD "%s"' % item]
-			result += ['NUMBER_OF_FIELDS %s' % len(data.parent['DATA_FORMAT'])]
-			result += ['BEGIN_DATA_FORMAT']
-			result += [' '.join(data.parent['DATA_FORMAT'].values())]
-			result += ['END_DATA_FORMAT']
-			result += ['']
-			result += ['NUMBER_OF_SETS %s' % (len(data))]
-			result += ['BEGIN_DATA']
+						result.append('KEYWORD "%s"' % item)
+			result.append('NUMBER_OF_FIELDS %s' % len(data.parent['DATA_FORMAT']))
+			result.append('BEGIN_DATA_FORMAT')
+			result.append(' '.join(data.parent['DATA_FORMAT'].values()))
+			result.append('END_DATA_FORMAT')
+			result.append('')
+			result.append('NUMBER_OF_SETS %s' % (len(data)))
+			result.append('BEGIN_DATA')
 			for key in data:
-				result += [' '.join([rpad(data[key][item], 
-										  data.vmaxlen + 
-										  (1 if data[key][item] < 0 else 0)) 
-									 for item in 
-									 data.parent['DATA_FORMAT'].values()])]
-			result += ['END_DATA']
+				result.append(' '.join([rpad(data[key][item], 
+											 data.vmaxlen + 
+											 (1 if data[key][item] < 0 else 0)) 
+										for item in 
+										data.parent['DATA_FORMAT'].values()]))
+			result.append('END_DATA')
 		return '\n'.join(result)
 
 	def add_keyword(self, keyword, value=None):
@@ -1418,7 +1421,7 @@ Transform {
 						item["XYZ_X"], item["XYZ_Y"], item["XYZ_Z"] = X, Y, Z
 		return n
 	
-	def apply_bpc(self, weight=False):
+	def apply_bpc(self, bp_out=(0, 0, 0), weight=False):
 		"""
 		Apply black point compensation.
 		
@@ -1432,6 +1435,7 @@ Transform {
 		n = 0
 		for dataset in self.query("DATA").itervalues():
 			if dataset.type.strip() == "CAL":
+				is_Lab = False
 				labels = ("RGB_R", "RGB_G", "RGB_B")
 				data = dataset.queryi(labels)
 
@@ -1448,8 +1452,15 @@ Transform {
 				for label in labels:
 					black.append(black1[label])
 					white.append(white1[label])
+				max_v = 1.0
 			else:
-				labels = ("XYZ_X", "XYZ_Y", "XYZ_Z")
+				is_Lab = "_LAB" in (dataset.queryv1("COLOR_REP") or "")
+				if is_Lab:
+					labels = ("LAB_L", "LAB_A", "LAB_B")
+					index = 0  # Index of L* in labels
+				else:
+					labels = ("XYZ_X", "XYZ_Y", "XYZ_Z")
+					index = 1  # Index of Y in labels
 				data = dataset.queryi(("RGB_R", "RGB_G", "RGB_B") + labels)
 
 				# Get blacks
@@ -1462,24 +1473,43 @@ Transform {
 
 				black = [0, 0, 0]
 				for i in blacks:
-					if blacks[i]["XYZ_Y"] > black[1]:
+					if blacks[i][labels[index]] > black[index]:
 						for j, label in enumerate(labels):
 							black[j] = blacks[i][label]
+				if is_Lab:
+					black = colormath.Lab2XYZ(*black)
 
 				white = [0, 0, 0]
 				for i in whites:
-					if whites[i]["XYZ_Y"] > white[1]:
+					if whites[i][labels[index]] > white[index]:
 						for j, label in enumerate(labels):
 							white[j] = whites[i][label]
+				if is_Lab:
+					max_v = 100.0
+					white = colormath.Lab2XYZ(*white)
+				else:
+					max_v = white[1]
+					black = [v / max_v for v in black]
+					white = [v / max_v for v in white]
 
 			# Apply black point compensation
 			n += 1
 			for i in data:
-				XYZ = data[i].queryv1(labels)
-				XYZ = colormath.apply_bpc(XYZ[0], XYZ[1], XYZ[2], black,
-										  (0, 0, 0), white, weight)
+				values = data[i].queryv1(labels).values()
+				if is_Lab:
+					values = colormath.Lab2XYZ(*values)
+				else:
+					values = [v / max_v for v in values]
+				values = colormath.apply_bpc(values[0], values[1], values[2], black,
+											bp_out, white, weight)
+				values = [v * max_v for v in values]
+				if is_Lab:
+					values = colormath.XYZ2Lab(*values)
 				for j, label in enumerate(labels):
-					data[i][label] = max(0.0, XYZ[j])
+					if is_Lab and j > 0:
+						data[i][label] = values[j]
+					else:
+						data[i][label] = max(0.0, values[j])
 
 		return n
 	
