@@ -4,8 +4,13 @@ import platform
 import sys
 
 if sys.platform == "darwin":
-	# Mac OS X has universal binaries
-	from lib.RealDisplaySizeMM import *
+	# Mac OS X has universal binaries in two flavors:
+	# - i386 & PPC
+	# - i386 & x86_64
+	if platform.architecture()[0].startswith('64'):
+		from lib64.RealDisplaySizeMM import *
+	else:
+		from lib32.RealDisplaySizeMM import *
 else:
 	# Linux and Windows have separate files
 	if platform.architecture()[0].startswith('64'):
