@@ -263,12 +263,21 @@ def apply_bpc(X, Y, Z, bp_in, bp_out, wp_out="D50", weight=False):
 	"""
 	wp_out = get_whitepoint(wp_out)
 	XYZ = [X, Y, Z]
-	bp_in = list(bp_in)
-	bp_out = list(bp_out)
+	if weight:
+		L = XYZ2Lab(*[v * 100 for v in (X, Y, Z)])[0]
+		bp_in_Lab = XYZ2Lab(*[v * 100 for v in bp_in])
+		bp_out_Lab = XYZ2Lab(*[v * 100 for v in bp_out])
+		vv = (L - bp_in_Lab[0]) / (100.0 - bp_in_Lab[0])  # 0 at bp, 1 at wp
+		vv = 1.0 - vv
+		if vv < 0.0:
+			vv = 0.0
+		elif vv > 1.0:
+			vv = 1.0
+		vv = math.pow(vv, min(40.0, 40.0 / (max(bp_in_Lab[0],
+												bp_out_Lab[0]) or 1.0)))
+		bp_in = Lab2XYZ(*[v * vv for v in bp_in_Lab])
+		bp_out = Lab2XYZ(*[v * vv for v in bp_out_Lab])
 	for i, v in enumerate(XYZ):
-		if weight and v > 0:
-			bp_in[i] *= (bp_in[i] / v)
-			bp_out[i] *= (bp_out[i] / v)
 		XYZ[i] = ((wp_out[i] - bp_out[i]) * v - wp_out[i] * (bp_in[i] - bp_out[i])) / (wp_out[i] - bp_in[i])
 	return XYZ
 
@@ -604,7 +613,7 @@ def DIN99bcdLCH2Lab(L99, C99, H99, x, l1, l2, deg, f1, c1, c2, whitepoint=None):
 	H99 -= deg
 	L, a, b = DIN99familyLHCG2Lab(L99, H99, C99, G, 1.0, l1, l2, deg, f1)
 	if x:
-		X, Y, Z = [v * 100 for v in Lab2XYZ(L, a, b, whitepoint)]
+		X, Y, Z = Lab2XYZ(L, a, b, whitepoint, scale=100)
 		X = (X + x * Z) / (1 + x)
 		L, a, b = XYZ2Lab(X, Y, Z, whitepoint)
 	return L, a, b
@@ -728,12 +737,12 @@ def Lab2DIN99b(L, a, b, kE=1.0):
 
 
 def Lab2DIN99c(L, a, b, kE=1.0, whitepoint=None):
-	X, Y, Z = [v * 100 for v in Lab2XYZ(L, a, b, whitepoint)]
+	X, Y, Z = Lab2XYZ(L, a, b, whitepoint, scale=100)
 	return XYZ2DIN99c(X, Y, Z, whitepoint)
 
 
 def Lab2DIN99d(L, a, b, kE=1.0, whitepoint=None):
-	X, Y, Z = [v * 100 for v in Lab2XYZ(L, a, b, whitepoint)]
+	X, Y, Z = Lab2XYZ(L, a, b, whitepoint, scale=100)
 	return XYZ2DIN99d(X, Y, Z, whitepoint)
 
 
@@ -1180,6 +1189,11 @@ def xyY2Lab(x, y, Y=1.0, whitepoint=None):
 	return XYZ2Lab(X, Y, Z, whitepoint)
 
 
+def xyY2Lu_v_(x, y, Y=1.0, whitepoint=None):
+	X, Y, Z = xyY2XYZ(x, y, Y)
+	return XYZ2Lu_v_(X, Y, Z, whitepoint)
+
+
 def xyY2RGB(x, y, Y, rgb_space=None, scale=1.0, round_=False, clamp=True):
 	""" Convert from xyY to RGB """
 	X, Y, Z = xyY2XYZ(x, y, Y)
@@ -1302,6 +1316,7 @@ def XYZ2CCT(X, Y, Z):
 
 
 def XYZ2DIN99(X, Y, Z, whitepoint=None):
+	X, Y, Z = (max(v, 0) for v in (X, Y, Z))
 	L, a, b = XYZ2Lab(X, Y, Z, whitepoint)
 	return Lab2DIN99(L, a, b)
 
@@ -1554,13 +1569,16 @@ def gam_fit(gf, v):
 		rv += 100.0 * -gamma
 		gamma = 1e-4
 
-	tt = math.pow(gf.roo, 1.0 / gamma)
-	b = tt / (1.0 - tt)  # Offset
-	a = math.pow(1.0 - tt, gamma)  # Gain
+	t1 = math.pow(gf.bp, 1.0 / gamma);
+	t2 = math.pow(gf.wp, 1.0 / gamma);
+	b = t1 / (t2 - t1)  # Offset
+	a = math.pow(t2 - t1, gamma)  # Gain
 
-	tt = a * math.pow(0.5 + b, gamma)
-	tt = tt - gf.thyr
-	rv += tt * tt
+	# Comput 50% output for this technical gamma
+	# (All values are without output offset being added in)
+	t1 = a * math.pow(0.5 + b, gamma)
+	t1 = t1 - gf.thyr
+	rv += t1 * t1
 	
 	return rv
 
@@ -1974,7 +1992,7 @@ def powell(di, cp, s, ftol, maxit, func, fdata, prog=None, pdata=None):
 	return False  # Failed due to execessive iterations
 
 
-def xicc_tech_gamma(egamma, off):
+def xicc_tech_gamma(egamma, off, outoffset=0.0):
 	# Adapted from ArgyllCMS xicc.c
 
 	"""
@@ -1989,8 +2007,11 @@ def xicc_tech_gamma(egamma, off):
 	if off <= 0.0:
 		return egamma
 
-	gf.thyr = math.pow(0.5, egamma)  # Advetised 50% target
-	gf.roo = off
+	# We set up targets without outo being added
+	outo = off * outoffset  # Offset acounted for in output
+	gf.bp = off - outo  # Black value for 0 % input
+	gf.wp = 1.0 - outo  # White value for 100% input
+	gf.thyr = math.pow(0.5, egamma) - outo  # Advetised 50% target
 
 	op[0] = egamma
 	sa[0] = 0.1
@@ -2004,9 +2025,10 @@ def xicc_tech_gamma(egamma, off):
 class gam_fits(object):
 	# Adapted from ArgyllCMS xicc/xicc.c
 
-	def __init__(self, thyr=.2, roo=0):
+	def __init__(self, wp=1.0, thyr=.2, bp=0.0):
+		self.wp = wp  # 100% input target
 		self.thyr = thyr  # 50% input target
-		self.roo = roo  # 0% input target
+		self.bp = bp  # 0% input target
 
 
 class Interp(object):
@@ -2029,27 +2051,45 @@ class BT1886(object):
 
 	""" BT.1886 like transfer function """
 
-	def __init__(self, matrix, XYZbp, gamma):
-		""" Setup the bt1886_info for the given target """
+	def __init__(self, matrix, XYZbp, outoffset=0.0, gamma=2.4):
+		""" Setup BT.1886 for the given target """
 		self.bwd_matrix = matrix.inverted()
 		self.fwd_matrix = matrix
 		self.gamma = gamma
 
-		Lab = XYZ2Lab(*XYZbp)
+		Lab = XYZ2Lab(*[v * 100 for v in XYZbp])
 
-		self.outL = Lab[0]  # For bp blend
-		self.tab = Lab[1:]  # a* b* correction needed
+		# For bp blend
+		self.outL = Lab[0]
+		# a* b* correction needed
+		self.tab = list(Lab)
+		self.tab[0] = 0  # 0 because bt1886 maps L to target
 
-		bkipow = math.pow(XYZbp[1], 1.0 / self.gamma)
-		self.ingo = bkipow / (1.0 - bkipow)  # non-linear Y that makes out black point
-		self.outsc = pow(1.0 - bkipow, self.gamma)  # Scale to restore 1 -> 1
+		if XYZbp[1] < 0:
+			XYZbp[1] = 0.0
+
+		# Offset acounted for in output
+		self.outo = XYZbp[1] * outoffset
+		# Balance of offset accounted for in input
+		ino = XYZbp[1] - self.outo
+
+		 # Input offset black to 1/pow
+		bkipow = math.pow(ino, 1.0 / self.gamma)
+		# Input offset white to 1/pow
+		wtipow = math.pow(1.0 - self.outo, 1.0 / self.gamma)
+		# non-linear Y that makes input offset proportion of black point
+		self.ingo = bkipow / (wtipow - bkipow)
+		# Scale to make input of 1 map to 1.0 - self.outo
+		self.outsc = pow(wtipow - bkipow, self.gamma)
 
 	def apply(self, X, Y, Z):
 		"""
 		Apply BT.1886 black offset and gamma curve to the XYZ out of the input profile.
 		Do this in the colorspace defined by the input profile matrix lookup,
 		so it will be relative XYZ. We assume that BT.1886 does a Rec709 to gamma
-		viewing adjustment, irrespective of the source profile transfer curve.
+		viewing adjustment, on top of any source profile transfer curve
+		(i.e. BT.1886 viewing adjustment is assumed to be the mismatch between
+		Rec709 curve and the output offset pure 2.4 gamma curve)
 		
 		"""
 
@@ -2068,12 +2108,16 @@ class BT1886(object):
 			else:
 				vv = 1.099 * math.pow(vv, 0.45) - 0.099
 			
-			# Apply input offset & re-scale, and then gamma of 2.4/custom gamma
+			# Apply input offset
 			vv = vv + self.ingo
-			
+
+			# Apply power and scale
 			if vv > 0.0:
 				vv = self.outsc * math.pow(vv, self.gamma)
 
+			# Apply output portion of offset
+			vv += self.outo
+
 			out[j] = vv
 
 		out = self.fwd_matrix * out
@@ -2083,7 +2127,7 @@ class BT1886(object):
 		out = list(XYZ2Lab(*[v * 100 for v in out]))
 
 		logging.debug("bt1886 Lab after Y adj. %f %f %f" % (out[0], out[1],
-															  out[2]))
+															out[2]))
 
 		# Blend ab to required black point offset self.tab[] as L approaches black.
 		vv = (out[0] - self.outL) / (100.0 - self.outL)  # 0 at bp, 1 at wp
@@ -2094,11 +2138,12 @@ class BT1886(object):
 		elif vv > 1.0:
 			vv = 1.0
 		vv = math.pow(vv, 40.0)
-		out[1] += vv * self.tab[0]
-		out[2] += vv * self.tab[1]
+		out[0] += vv * self.tab[0]
+		out[1] += vv * self.tab[1]
+		out[2] += vv * self.tab[2]
 
 		logging.debug("bt1886 Lab after wp adj. %f %f %f" % (out[0], out[1],
-															   out[2]))
+															 out[2]))
 
 		out = Lab2XYZ(*out)
 
