@@ -11,6 +11,7 @@ import locale
 import math
 import os
 import re
+import string
 import sys
 from time import gmtime, strftime, timezone
 if sys.platform == "win32":
@@ -53,9 +54,10 @@ if isexe and os.getenv("_MEIPASS2"):
 pyfile = (exe if isexe else (os.path.isfile(sys.argv[0]) and sys.argv[0]) or
 		  os.path.join(os.path.dirname(__file__), "main.py"))
 pypath = exe if isexe else os.path.abspath(unicode(pyfile, fs_enc))
+# Mac OS X: isapp should only be true for standalone, not 0install
 isapp = sys.platform == "darwin" and \
 		exe.split(os.path.sep)[-3:-1] == ["Contents", "MacOS"] and \
-		os.path.isfile(os.path.join(exedir, appname))
+		os.path.exists(os.path.join(exedir, "..", "Resources", "xrc"))
 if isapp:
 	pyname, pyext = os.path.splitext(exe.split(os.path.sep)[-4])
 	pydir = os.path.normpath(os.path.join(exedir, "..", "Resources"))
@@ -74,17 +76,16 @@ if sys.platform == "win32":
 		# subfolders of the executable directory which are not in 
 		# Lib\site-packages\dispcalGUI can be found
 		# (e.g. Scripts\dispcalGUI-apply-profiles)
-		data_dirs += [exedir]
+		data_dirs.append(exedir)
 	script_ext = ".cmd"
 	scale_adjustment_factor = 1.0
 	config_sys = os.path.join(commonappdata[0], appname)
 	confighome = os.path.join(appdata, appname)
 	datahome = os.path.join(appdata, appname)
 	logdir = os.path.join(datahome, "logs")
-	data_dirs += [datahome]
-	data_dirs += [os.path.join(dir_, appname) for dir_ in commonappdata]
-	del dir_
-	data_dirs += [os.path.join(commonprogramfiles, appname)]
+	data_dirs.append(datahome)
+	data_dirs.extend(os.path.join(dir_, appname) for dir_ in commonappdata)
+	data_dirs.append(os.path.join(commonprogramfiles, appname))
 	exe_ext = ".exe"
 	profile_ext = ".icm"
 else:
@@ -97,7 +98,7 @@ else:
 		datahome = os.path.join(appdata, appname)
 		logdir = os.path.join(expanduseru("~"), "Library", 
 							  "Logs", appname)
-		data_dirs += [datahome, os.path.join(commonappdata[0], appname)]
+		data_dirs.extend([datahome, os.path.join(commonappdata[0], appname)])
 	else:
 		script_ext = ".sh"
 		scale_adjustment_factor = 1.0
@@ -106,15 +107,14 @@ else:
 		datahome = os.path.join(xdg_data_home, appname)
 		datahome_default = os.path.join(xdg_data_home_default, appname)
 		logdir = os.path.join(datahome, "logs")
-		data_dirs += [datahome]
+		data_dirs.append(datahome)
 		if not datahome_default in data_dirs:
-			data_dirs += [datahome_default]
-		data_dirs += [os.path.join(dir_, appname) for dir_ in xdg_data_dirs]
-		data_dirs += [os.path.join(dir_, "argyllcms") for dir_ in
-					  xdg_data_dirs]
-		data_dirs += [os.path.join(dir_, "color", "argyll") for dir_ in
-					  xdg_data_dirs]
-		del dir_
+			data_dirs.append(datahome_default)
+		data_dirs.extend(os.path.join(dir_, appname) for dir_ in xdg_data_dirs)
+		data_dirs.extend(os.path.join(dir_, "argyllcms") for dir_ in
+						 xdg_data_dirs)
+		data_dirs.extend(os.path.join(dir_, "color", "argyll") for dir_ in
+						 xdg_data_dirs)
 	exe_ext = ""
 	profile_ext = ".icc"
 
@@ -142,6 +142,16 @@ resfiles = [
 
 bitmaps = {}
 
+uncalibratable_displays = ("Untethered", )
+
+patterngenerators = ("madVR", "Resolve")
+
+non_argyll_displays = uncalibratable_displays + ("Resolve", )
+
+untethered_displays = non_argyll_displays + ("Web", )
+
+virtual_displays = untethered_displays + ("madVR", )
+
 def getbitmap(name):
 	"""
 	Create (if necessary) and return a named bitmap.
@@ -256,7 +266,7 @@ def get_display_number(display_no):
 	except IndexError:
 		return 0
 	else:
-		if display in ("Web @ localhost", "Untethered", "madVR"):
+		if display.split("@")[0].strip() in virtual_displays:
 			return 0
 		for i in xrange(wx.Display.GetCount()):
 			geometry = "%i, %i, %ix%i" % tuple(wx.Display(i).Geometry)
@@ -316,9 +326,13 @@ def get_data_path(relpath, rex=None):
 		(isinstance(os.path.altsep, basestring) and
 		 relpath.endswith(os.path.altsep))):
 		return None
+	dirs = list(data_dirs)
+	argyll_dir = getcfg("argyll.dir")
+	if argyll_dir and os.path.isdir(os.path.join(argyll_dir, "..", "ref")):
+		dirs.append(os.path.dirname(argyll_dir))
 	intersection = []
 	paths = []
-	for dir_ in data_dirs:
+	for dir_ in dirs:
 		curpath = os.path.join(dir_, relpath)
 		if (dir_.endswith("/argyll") and (relpath + "/").startswith("ref/") and
 			not os.path.exists(curpath)):
@@ -332,6 +346,7 @@ def get_data_path(relpath, rex=None):
 			else:
 				curpath = dir_
 		if os.path.exists(curpath):
+			curpath = os.path.normpath(curpath)
 			if os.path.isdir(curpath):
 				try:
 					filelist = listdir_re(curpath, rex)
@@ -342,8 +357,8 @@ def get_data_path(relpath, rex=None):
 				else:
 					for filename in filelist:
 						if not filename in intersection:
-							intersection += [filename]
-							paths += [os.path.join(curpath, filename)]
+							intersection.append(filename)
+							paths.append(os.path.join(curpath, filename))
 			else:
 				return curpath
 	if paths:
@@ -428,7 +443,8 @@ cfg = ConfigParser.RawConfigParser()
 cfg.optionxform = str
 
 valid_ranges = {
-	"3dlut.bt1886_gamma": [0.000001, 10],
+	"3dlut.trc_gamma": [0.000001, 10],
+	"3dlut.trc_output_offset": [0.0, 1.0],
 	"gamma": [0.000001, 10],
 	"trc": [0.000001, 10],
 	"calibration.ambient_viewcond_adjust.lux": [0, sys.maxint],
@@ -437,7 +453,12 @@ valid_ranges = {
 	"calibration.black_point_correction": [0, 1],
 	"calibration.black_point_rate": [0.05, 20],
 	"calibration.luminance": [0.000001, 100000],
-	"measurement_report.bt1886_gamma": [0.01, 10],
+	"measurement_report.trc_gamma": [0.01, 10],
+	"measurement_report.trc_output_offset": [0.0, 1.0],
+	"measure.display_settle_time_mult": [0.000001, 10000.0],
+	"measure.min_display_update_delay_ms": [20, 60000],
+	"patterngenerator.apl": [0.0, 1.0],
+	"synthprofile.trc_output_offset": [0.0, 1.0],
 	"tc_export_repeat_patch_max": [1, 1000],
 	"tc_export_repeat_patch_min": [1, 1000],
 	"tc_vrml_black_offset": [0, 40],
@@ -449,12 +470,12 @@ valid_values = {
 	"3d.format": ["HTML", "VRML", "X3D"],
 	"3dlut.bitdepth.input": [8, 10, 12, 14, 16],
 	"3dlut.bitdepth.output": [8, 10, 12, 14, 16],
-	"3dlut.bt1886_gamma_type": ["b", "B"],
 	"3dlut.encoding.input": video_encodings,
 	"3dlut.encoding.output": video_encodings,
 	"3dlut.format": ["3dl", "cube", "eeColor", "madVR", "mga", "spi3d"],
 	"3dlut.rendering_intent": intents,
 	"3dlut.size": [17, 24, 32, 33, 64, 65],
+	"3dlut.trc_gamma_type": ["b", "B"],
 	"calibration.quality": ["v", "l", "m", "h", "u"],
 	# Measurement modes as supported by Argyll -y parameter
 	# 'l' = 'n' (non-refresh-type display, e.g. LCD)
@@ -463,41 +484,42 @@ valid_values = {
 	# worker.Worker.add_measurement_features if using Argyll >= 1.5
 	# See http://www.argyllcms.com/doc/instruments.html
 	# for description of per-instrument supported modes
-	"measurement_mode": [None, "B", "F", "L", "R", "a", "b", "c", "e", "f", "g",
-						 "l", "m", "n", "o", "p", "r", "x", "1", "2", "3", "4", 
-						 "5", "6", "7", "8", "9", "auto"],
+	"measurement_mode": [None, "auto"] + list(string.digits[1:] +
+											  string.ascii_letters),
 	"gamap_default_intent": ["a", "r", "p", "s"],
 	"gamap_perceptual_intent": intents,
 	"gamap_saturation_intent": intents,
 	"gamap_src_viewcond": viewconds,
 	"gamap_out_viewcond": ["mt", "mb", "md", "jm", "jd"],
 	"measure.uniformity.show_detail": [0, 1],
-	"measurement_report.bt1886_gamma_type": ["b", "B"],
+	"measurement_report.trc_gamma_type": ["b", "B"],
+	"patterngenerator.resolve.use_video_levels": [0, 1],
 	"profile.black_point_compensation": [0, 1],
 	"profile.install_scope": ["l", "u"],
 	"profile.quality": ["l", "m", "h", "u"],
 	"profile.quality.b2a": ["l", "m", "h", "u", "n", None],
-	"profile.b2a.smooth.size": [9, 17, 33, 45, 65],
+	"profile.b2a.hires.size": [9, 17, 33, 45, 65],
 	"profile.type": ["g", "G", "l", "s", "S", "x", "X"],
 	"synthprofile.black_point_compensation": [0, 1],
-	"synthprofile.trc_type": ["g", "G"],
+	"synthprofile.trc_gamma_type": ["g", "G"],
 	"tc_algo": ["", "t", "r", "R", "q", "Q", "i", "I"],  # Q = Argyll >= 1.1.0
 	"tc_vrml_use_D50": [0, 1],
 	"tc_vrml_cie_colorspace": ["DIN99", "DIN99b", "DIN99c", "DIN99d", "LCH(ab)",
 							   "LCH(uv)", "Lab", "Luv", "Lu'v'", "xyY"],
 	"tc_vrml_device_colorspace": ["HSI", "HSL", "HSV", "RGB"],
-	"trc": ["240", "709", "l", "s"],
+	"trc": ["240", "709", "l", "s", ""],
 	"trc.type": ["g", "G"],
 	"whitepoint.colortemp.locus": ["t", "T"]
 }
 
 defaults = {
 	"3d.format": "HTML",
-	"3dlut.apply_bt1886_gamma_mapping": 1,
+	"3dlut.apply_trc": 1,
 	"3dlut.bitdepth.input": 10,
 	"3dlut.bitdepth.output": 10,
-	"3dlut.bt1886_gamma": 2.4,
-	"3dlut.bt1886_gamma_type": "B",
+	"3dlut.trc_gamma": 2.4,
+	"3dlut.trc_gamma_type": "B",
+	"3dlut.trc_output_offset": 0.0,
 	"3dlut.encoding.input": "n",
 	"3dlut.encoding.input.backup": "n",
 	"3dlut.encoding.output": "n",
@@ -513,13 +535,15 @@ defaults = {
 	"3dlut.size": 17,
 	"allow_skip_sensor_cal": 0,
 	"argyll.debug": 0,
-	"argyll.dir": expanduseru("~"), # directory
+	"argyll.dir": None,
 	"argyll.version": "0.0.0",
 	"drift_compensation.blacklevel": 0,
 	"drift_compensation.whitelevel": 0,
 	"calibration.ambient_viewcond_adjust": 0,
 	"calibration.ambient_viewcond_adjust.lux": 500.0,
+	"calibration.autoload": 0,
 	"calibration.black_luminance": 0.000001,
+	"calibration.black_luminance.backup": 0.000001,
 	"calibration.black_output_offset": 1.0,
 	"calibration.black_output_offset.backup": 1.0,
 	"calibration.black_point_correction": 0.0,
@@ -527,10 +551,13 @@ defaults = {
 	"calibration.black_point_correction_choice.show": 1,
 	"calibration.black_point_rate": 4.0,
 	"calibration.black_point_rate.enabled": 0,
+	"calibration.continue_next": 0,
 	"calibration.file": None,
 	"calibration.file.previous": None,
 	"calibration.interactive_display_adjustment": 1,
+	"calibration.interactive_display_adjustment.backup": 1,
 	"calibration.luminance": 120.0,
+	"calibration.luminance.backup": 120.0,
 	"calibration.quality": "m",
 	"calibration.update": 0,
 	"calibration.use_video_lut": 1,
@@ -575,9 +602,10 @@ defaults = {
 	"measurement_mode.backup": "l",
 	"measurement_mode.highres": 0,
 	"measurement_mode.projector": 0,
-	"measurement_report.apply_bt1886_gamma_mapping": 0,
-	"measurement_report.bt1886_gamma": 2.4,
-	"measurement_report.bt1886_gamma_type": "B",
+	"measurement_report.apply_trc": 0,
+	"measurement_report.trc_gamma": 2.4,
+	"measurement_report.trc_gamma_type": "B",
+	"measurement_report.trc_output_offset": 0.0,
 	"measurement_report.chart": "",
 	"measurement_report.chart.fields": "RGB",
 	"measurement_report.devlink_profile": "",
@@ -594,7 +622,19 @@ defaults = {
 	"measurement.save_path": expanduseru("~"),
 	"measure.darken_background": 0,
 	"measure.darken_background.show_warning": 1,
+	"measure.display_settle_time_mult": 1.0,
+	"measure.display_settle_time_mult.backup": 1.0,
+	"measure.min_display_update_delay_ms": 20,
+	"measure.min_display_update_delay_ms.backup": 20,
+	"measure.override_display_settle_time_mult": 0,
+	"measure.override_display_settle_time_mult.backup": 0,
+	"measure.override_min_display_update_delay_ms": 0,
+	"measure.override_min_display_update_delay_ms.backup": 0,
 	"measure.uniformity.show_detail": 0,
+	"patterngenerator.apl": .22,
+	"patterngenerator.resolve.bits": 10,
+	"patterngenerator.resolve.port": 20002,
+	"patterngenerator.resolve.use_video_levels": 0,
 	"position.x": 50,
 	"position.y": 50,
 	"position.info.x": 50,
@@ -637,10 +677,10 @@ defaults = {
 	"profile.name.expanded": u"",
 	"profile.quality": "h",
 	"profile.quality.b2a": "h",
-	"profile.b2a.smooth": 1,
-	"profile.b2a.smooth.diagpng": 1,
-	"profile.b2a.smooth.extra": 1,
-	"profile.b2a.smooth.size": 33,
+	"profile.b2a.hires": 1,
+	"profile.b2a.hires.diagpng": 1,
+	"profile.b2a.hires.size": 33,
+	"profile.b2a.hires.smooth": 1,
 	"profile.save_path": storage, # directory
 	"profile.type": "S",
 	"profile.update": 0,
@@ -654,21 +694,24 @@ defaults = {
 	"size.info.h": 384,
 	"size.lut3dframe.w": 512,
 	"size.lut3dframe.h": 384,
+	"size.measureframe": 300,
 	"size.profile_info.w": 432,
 	"size.profile_info.split.w": 960,
-	"size.profile_info.h": 524,
-	"size.lut_viewer.w": 512,
-	"size.lut_viewer.h": 580,
+	"size.profile_info.h": 552,
+	"size.lut_viewer.w": 432,
+	"size.lut_viewer.h": 552,
 	"size.reportframe.w": 512,
 	"size.reportframe.h": 256,
 	"size.synthiccframe.w": 512,
 	"size.synthiccframe.h": 384,
 	"skip_legacy_serial_ports": 1,
+	"skip_scripts": 1,
 	"sudo.preserve_environment": 1,
 	"synthprofile.black_luminance": 0.0,
-	"synthprofile.gamma": 2.4,
 	"synthprofile.luminance": 120.0,
-	"synthprofile.trc_type": "G",
+	"synthprofile.trc_gamma": 2.4,
+	"synthprofile.trc_gamma_type": "G",
+	"synthprofile.trc_output_offset": 0.0,
 	"tc_adaption": 0.1,
 	"tc_add_ti3_relative": 1,
 	"tc_algo": "",
@@ -721,9 +764,12 @@ defaults = {
 	"vrml.compress": 1,
 	"webserver.portnumber": 8080,
 	"whitepoint.colortemp": 5000,
+	"whitepoint.colortemp.backup": 5000,
 	"whitepoint.colortemp.locus": "t",
 	"whitepoint.x": 0.345741,
+	"whitepoint.x.backup": 0.345741,
 	"whitepoint.y": 0.358666,
+	"whitepoint.y.backup": 0.358666,
 	"x3dom.cache": 1,
 	"x3dom.embed": 0
 }
@@ -897,7 +943,7 @@ def get_current_profile(include_display_profile=False):
 def get_display_profile(display_no=None):
 	if display_no is None:
 		display_no = max(getcfg("display.number") - 1, 0)
-	if get_display_name(display_no) in ("Web", "Untethered", "madVR"):
+	if get_display_name(display_no) in virtual_displays:
 		return None
 	import ICCProfile as ICCP
 	try:
@@ -1005,12 +1051,12 @@ def get_total_patches(white_patches=None, black_patches=None,
 		if multi_bcc_steps > 1:
 			multi_bcc_step = multi_step
 			for i in range(multi_bcc_steps):
-				multi_values += [str(multi_bcc_step  * i)]
+				multi_values.append(str(multi_bcc_step  * i))
 			for i in range(multi_bcc_steps * 2 - 1):
-				multi_bcc_values += [str(multi_bcc_step / 2.0  * i)]
+				multi_bcc_values.append(str(multi_bcc_step / 2.0  * i))
 		else:
 			for i in range(multi_steps):
-				multi_values += [str(multi_step * i)]
+				multi_values.append(str(multi_step * i))
 		if single_channel_patches > 1:
 			single_channel_step = 255.0 / (single_channel_patches - 1)
 			for i in range(single_channel_patches):
@@ -1217,9 +1263,10 @@ def writecfg(which="user", worker=None):
 			cfgfilename = cfgfilename1
 		try:
 			cfgfile = open(cfgfilename, "wb")
-			cfgfile.write("\n".join(["[Default]",
-									 "%s = %s" % ("argyll.dir", 
-												  getcfg("argyll.dir"))]))
+			if getcfg("argyll.dir"):
+				cfgfile.write("\n".join(["[Default]",
+										 "%s = %s" % ("argyll.dir", 
+													  getcfg("argyll.dir"))]))
 			cfgfile.close()
 			if sys.platform != "win32":
 				# on Linux and OS X, we write the file to the users's config dir
