@@ -9,6 +9,8 @@ Interactive display calibration UI
 import os
 import re
 import sys
+if sys.platform == "win32":
+	from ctypes import windll
 
 from wxaddons import wx
 from lib.agw import labelbook
@@ -16,10 +18,11 @@ from lib.agw.fmresources import *
 from lib.agw.pygauge import PyGauge
 
 from config import get_data_path, get_icon_bundle, getbitmap, getcfg, setcfg
+from config import enc
 from log import get_file_logger
 from meta import name as appname
 from ordereddict import OrderedDict
-from util_str import wrap
+from util_str import safe_unicode, wrap
 from wxwindows import FlatShadedButton, numpad_keycodes
 import config
 import localization as lang
@@ -442,12 +445,10 @@ class DisplayAdjustmentPanel(wx.Panel):
 		self.SetForegroundColour(FGCOLOUR)
 		self.SetSizer(wx.BoxSizer(wx.VERTICAL))
 		self.title_txt = wx.StaticText(self, wx.ID_ANY, title)
-		if sys.platform == "darwin":
-			fontsize = 11
-		else:
-			fontsize = 10
-		self.title_txt.SetFont(wx.Font(fontsize, wx.FONTFAMILY_DEFAULT,
-							   wx.FONTSTYLE_NORMAL, wx.FONTWEIGHT_BOLD))
+		font = self.title_txt.GetFont()
+		font.SetPointSize(font.PointSize + 1)
+		font.SetWeight(wx.FONTWEIGHT_BOLD)
+		self.title_txt.SetFont(font)
 		self.title_txt.SetForegroundColour(FGCOLOUR)
 		self.GetSizer().Add(self.title_txt)
 		self.sizer = wx.FlexGridSizer(0, 2, 0, 0)
@@ -710,7 +711,7 @@ class DisplayAdjustmentFrame(wx.Frame):
 								   self.measurement_play_sound_handler)
 		self.btnsizer.Add(get_panel(self, (12, 12)), flag=wx.EXPAND)
 		self.calibration_btn = self.create_gradient_button(getbitmap("theme/icons/10x10/skip"),
-														   " " + lang.getstr("calibration.start"),
+														   "",
 														   name="calibration_btn")
 		self.calibration_btn.Bind(wx.EVT_BUTTON, self.continue_to_calibration)
 		self.calibration_btn.Disable()
@@ -731,7 +732,7 @@ class DisplayAdjustmentFrame(wx.Frame):
 			accels = []
 			for id, keycode in self.id_to_keycode.iteritems():
 				self.Bind(wx.EVT_MENU, self.key_handler, id=id)
-				accels += [(wx.ACCEL_NORMAL, keycode, id)]
+				accels.append((wx.ACCEL_NORMAL, keycode, id))
 			self.SetAcceleratorTable(wx.AcceleratorTable(accels))
 		else:
 			self.Bind(wx.EVT_CHAR_HOOK, self.key_handler)
@@ -792,23 +793,26 @@ class DisplayAdjustmentFrame(wx.Frame):
 		event.Skip()
 
 	def Pulse(self, msg=""):
-		if ((msg in (lang.getstr("instrument.initializing"),
-					 lang.getstr("instrument.calibrating"),
-					 lang.getstr("please_wait"),
-					 lang.getstr("aborting")) or msg == " " * 4 or
-			 "error" in msg.lower() or "failed" in msg.lower() or
-			 msg.startswith(lang.getstr("webserver.waiting"))) and
-			msg != self.lastmsg):
-			self.lastmsg = msg
-			self.Freeze()
-			for txt in self.lb.GetCurrentPage().txt.itervalues():
-				txt.checkmark.GetContainingSizer().Hide(txt.checkmark)
-				txt.SetLabel(" ")
-			txt = self.lb.GetCurrentPage().txt.values()[0]
-			if txt.GetLabel() != wrap(msg, 46):
-				txt.SetLabel(wrap(msg, 46))
-				txt.SetForegroundColour(FGCOLOUR)
-			self.Thaw()
+		if msg:
+			msg = safe_unicode(msg, enc)
+			if ((msg in (lang.getstr("instrument.initializing"),
+						 lang.getstr("instrument.calibrating"),
+						 lang.getstr("please_wait"),
+						 lang.getstr("aborting")) or msg == " " * 4 or
+				 ": error -" in msg.lower() or "failed" in msg.lower() or
+				 msg.startswith(lang.getstr("webserver.waiting")) or
+				 msg.startswith(lang.getstr("connection.waiting"))) and
+				msg != self.lastmsg):
+				self.lastmsg = msg
+				self.Freeze()
+				for txt in self.lb.GetCurrentPage().txt.itervalues():
+					txt.checkmark.GetContainingSizer().Hide(txt.checkmark)
+					txt.SetLabel(" ")
+				txt = self.lb.GetCurrentPage().txt.values()[0]
+				if txt.GetLabel() != wrap(msg, 46):
+					txt.SetLabel(wrap(msg, 46))
+					txt.SetForegroundColour(FGCOLOUR)
+				self.Thaw()
 		return self.keepGoing, False
 	
 	def Resume(self):
@@ -847,6 +851,17 @@ class DisplayAdjustmentFrame(wx.Frame):
 		else:
 			self.lb.disabled_pages = (0, 3)
 			self.lb.SetSelection(1)
+		if getcfg("trc"):
+			self.calibration_btn.SetLabel(" " + lang.getstr("calibration.start"))
+		elif getcfg("calibration.continue_next"):
+			self.calibration_btn.SetLabel(" " + lang.getstr("calibration.skip"))
+		else:
+			self.calibration_btn.SetLabel(" " + lang.getstr("finish"))
+		for btn in (self.adjustment_btn, self.sound_on_off_btn,
+					self.calibration_btn):
+			if hasattr(btn, "_lastBestSize"):
+				del btn._lastBestSize
+		self.calibration_btn.GetContainingSizer().Layout()
 		# Update black luminance page description
 		self.lb.GetPage(0).update_desc()
 		# Update white luminance page description
@@ -855,7 +870,7 @@ class DisplayAdjustmentFrame(wx.Frame):
 		# Set size
 		min_h = (72 + 8) * (self.lb.GetPageCount() - len(self.lb.disabled_pages)) + 2 - 8
 		if init:
-			self.lb.SetMinSize((350, min_h))
+			self.lb.SetMinSize((418, min_h))
 		self.lb.SetMinSize((self.lb.GetMinSize()[0],
 							max(self.lb.GetMinSize()[1], min_h)))
 		self.lb.GetCurrentPage().Fit()
@@ -872,7 +887,7 @@ class DisplayAdjustmentFrame(wx.Frame):
 			page = self.lb.GetPage(pagenum)
 			page.SetSize((w, -1))
 			page.desc.SetLabel(page.desc.GetLabel().replace("\n", " "))
-			page.desc.Wrap(w)
+			page.desc.Wrap(w - 12)
 			bitmaps = {"black_level": {CRT: "luminance",
 									   not CRT: "black_level"},
 					   "luminance": {CRT: "contrast",
@@ -896,9 +911,8 @@ class DisplayAdjustmentFrame(wx.Frame):
 		self.lb.SetMinSize((self.lb.GetMinSize()[0],
 							max(self.lb.GetCurrentPage().GetSize()[1], min_h)))
 		self.Fit()
-		self.Layout()
-		self.SetSize((self.GetSize()[0], self.GetSize()[1]))
-		self.SetMinSize(self.GetSize())
+		self.Sizer.SetSizeHints(self)
+		self.Sizer.Layout()
 		
 		# Set position
 		x = getcfg("position.progress.x")
@@ -924,7 +938,10 @@ class DisplayAdjustmentFrame(wx.Frame):
 		return panel
 	
 	def continue_to_calibration(self, event=None):
-		self.abort_and_send("7")
+		if getcfg("trc"):
+			self.abort_and_send("7")
+		else:
+			self.abort_and_send("8")
 	
 	def create_start_interactive_adjustment_button(self, icon="play",
 												   enable=False,
@@ -990,12 +1007,14 @@ class DisplayAdjustmentFrame(wx.Frame):
 				key_num = chr(keycode)
 				pagenum = dict(zip(self.pagenum_2_argyll_key_num.values(),
 								   self.pagenum_2_argyll_key_num.keys())).get(key_num)
-				if getcfg("measurement_mode") != "c" or pagenum not in self.lb.disabled_pages:
-					if pagenum is not None and not self.is_measuring:
-						self.lb.SetSelection(pagenum)
-						self.start_interactive_adjustment()
+				if pagenum not in self.lb.disabled_pages and not self.is_measuring:
+					self.lb.SetSelection(pagenum)
+					self.start_interactive_adjustment()
 			elif keycode in (ord("\x1b"), ord("7"), ord("8"), ord("Q"), ord("q")):
-				if self.keyhandler:
+				if not getcfg("trc") and keycode == ord("7"):
+					# Ignore
+					pass
+				elif self.keyhandler:
 					self.keyhandler(event)
 				elif self.has_worker_subprocess():
 					self.worker.safe_send(chr(keycode))
@@ -1022,8 +1041,7 @@ class DisplayAdjustmentFrame(wx.Frame):
 		if not txt:
 			return
 		self.logger.info("%r" % txt)
-		if "Setting up the instrument" in txt:
-			self.Pulse(lang.getstr("instrument.initializing"))
+		self.Pulse(txt)
 		
 		if "/ Current" in txt:
 			indicator = getbitmap("theme/icons/10x10/record")
