@@ -14,10 +14,8 @@ import config
 import localization as lang
 import worker
 from worker import check_set_argyll_bin
-from wxaddons import FileDrop
-from wxwindows import (BaseFrame, ConfirmDialog,
-					   FileBrowseBitmapButtonWithChoiceHistory as FileBrowse,
-					   InfoDialog, wx)
+from wxwindows import (BaseFrame, ConfirmDialog, FileDrop, InfoDialog, wx)
+import xh_filebrowsebutton
 
 from wx import xrc
 
@@ -29,6 +27,7 @@ class LUT3DFrame(BaseFrame):
 	def __init__(self, parent=None):
 		self.res = xrc.XmlResource(get_data_path(os.path.join("xrc", 
 															  "3dlut.xrc")))
+		self.res.InsertHandler(xh_filebrowsebutton.FileBrowseButtonWithHistoryXmlHandler())
 		pre = wx.PreFrame()
 		self.res.LoadOnFrame(pre, parent, "lut3dframe")
 		self.PostCreate(pre)
@@ -44,6 +43,20 @@ class LUT3DFrame(BaseFrame):
 		self.worker = worker.Worker(self)
 		self.worker.set_argyll_version("collink")
 
+		for which in ("input", "abstract", "output"):
+			ctrl = self.FindWindowByName("%s_profile_ctrl" % which)
+			setattr(self, "%s_profile_ctrl" % which, ctrl)
+			ctrl.changeCallback = getattr(self, "%s_profile_ctrl_handler" % 
+												which)
+			if which not in ("abstract", "output"):
+				ctrl.SetHistory(get_data_path("ref", "\.(icc|icm)$"))
+			ctrl.SetMaxFontSize(11)
+			# Drop targets
+			droptarget = FileDrop(self,
+								  {".icc": getattr(self, "%s_drop_handler" % which),
+								   ".icm": getattr(self, "%s_drop_handler" % which)})
+			ctrl.SetDropTarget(droptarget)
+
 		# Bind event handlers
 		self.abstract_profile_cb.Bind(wx.EVT_CHECKBOX,
 									  self.use_abstract_profile_ctrl_handler)
@@ -53,12 +66,19 @@ class LUT3DFrame(BaseFrame):
 		self.encoding_input_ctrl.Bind(wx.EVT_CHOICE,
 											self.encoding_input_ctrl_handler)
 		self.encoding_output_ctrl.Bind(wx.EVT_CHOICE,
-											 self.encoding_output_ctrl_handler)
-		self.apply_bt1886_cb.Bind(wx.EVT_CHECKBOX, self.apply_bt1886_ctrl_handler)
-		self.bt1886_gamma_ctrl.Bind(wx.EVT_KILL_FOCUS,
-									self.bt1886_gamma_ctrl_handler)
-		self.bt1886_gamma_type_ctrl.Bind(wx.EVT_CHOICE,
-										 self.bt1886_gamma_type_ctrl_handler)
+									   self.encoding_output_ctrl_handler)
+		self.apply_trc_cb.Bind(wx.EVT_CHECKBOX, self.apply_trc_ctrl_handler)
+		self.trc_ctrl.Bind(wx.EVT_CHOICE, self.trc_ctrl_handler)
+		self.trc_gamma_ctrl.Bind(wx.EVT_COMBOBOX,
+								 self.trc_gamma_ctrl_handler)
+		self.trc_gamma_ctrl.Bind(wx.EVT_KILL_FOCUS,
+								 self.trc_gamma_ctrl_handler)
+		self.trc_gamma_type_ctrl.Bind(wx.EVT_CHOICE,
+									  self.trc_gamma_type_ctrl_handler)
+		self.black_output_offset_ctrl.Bind(wx.EVT_SLIDER,
+										   self.black_output_offset_ctrl_handler)
+		self.black_output_offset_intctrl.Bind(wx.EVT_TEXT,
+											  self.black_output_offset_ctrl_handler)
 		self.rendering_intent_ctrl.Bind(wx.EVT_CHOICE,
 										self.rendering_intent_ctrl_handler)
 		self.lut3d_format_ctrl.Bind(wx.EVT_CHOICE,
@@ -95,6 +115,10 @@ class LUT3DFrame(BaseFrame):
 			self.Center()
 	
 	def OnClose(self, event=None):
+		if (getattr(self.worker, "thread", None) and
+			self.worker.thread.isAlive()):
+			self.worker.abort_subprocess(True)
+			return
 		if (self.IsShownOnScreen() and not self.IsMaximized() and
 			not self.IsIconized()):
 			x, y = self.GetScreenPosition()
@@ -114,55 +138,69 @@ class LUT3DFrame(BaseFrame):
 		self.abstract_profile_ctrl.Enable(enable)
 		self.abstract_profile_desc.Enable(enable)
 	
-	def apply_bt1886_ctrl_handler(self, event):
-		v = self.apply_bt1886_cb.GetValue()
-		self.bt1886_gamma_ctrl.Enable(v)
-		self.bt1886_gamma_type_ctrl.Enable(v)
-		setcfg("3dlut.apply_bt1886_gamma_mapping", int(v))
-		config.writecfg()
+	def apply_trc_ctrl_handler(self, event=None):
+		v = self.apply_trc_cb.GetValue()
+		self.trc_ctrl.Enable(v)
+		self.trc_gamma_label.Enable(v)
+		self.trc_gamma_ctrl.Enable(v)
+		self.trc_gamma_type_ctrl.Enable(v)
+		if event:
+			setcfg("3dlut.apply_trc", int(v))
+			config.writecfg()
+		self.black_output_offset_label.Enable(v)
+		self.black_output_offset_ctrl.Enable(v)
+		self.black_output_offset_intctrl.Enable(v)
+		self.black_output_offset_intctrl_label.Enable(v)
 	
 	def apply_cal_ctrl_handler(self, event):
 		setcfg("3dlut.output.profile.apply_cal",
 			   int(self.apply_cal_cb.GetValue()))
 		config.writecfg()
 
-	def abstract_drop_unsupported_handler(self):
-		self.drop_unsupported("abstract")
+	def black_output_offset_ctrl_handler(self, event):
+		if event.GetId() == self.black_output_offset_intctrl.GetId():
+			self.black_output_offset_ctrl.SetValue(
+				self.black_output_offset_intctrl.GetValue())
+		else:
+			self.black_output_offset_intctrl.SetValue(
+				self.black_output_offset_ctrl.GetValue())
+		v = self.black_output_offset_ctrl.GetValue() / 100.0
+		if v > 0:
+			self.trc_ctrl.SetSelection(1)  # Gamma
+		setcfg("3dlut.trc_output_offset", v)
+		self.update_trc_control()
 
-	def bt1886_gamma_ctrl_handler(self, event):
+	def trc_gamma_ctrl_handler(self, event):
 		try:
-			v = float(self.bt1886_gamma_ctrl.GetValue().replace(",", "."))
-			if (v < config.valid_ranges["3dlut.bt1886_gamma"][0] or
-				v > config.valid_ranges["3dlut.bt1886_gamma"][1]):
+			v = float(self.trc_gamma_ctrl.GetValue().replace(",", "."))
+			if (v < config.valid_ranges["3dlut.trc_gamma"][0] or
+				v > config.valid_ranges["3dlut.trc_gamma"][1]):
 				raise ValueError()
 		except ValueError:
 			wx.Bell()
-			self.bt1886_gamma_ctrl.SetValue(str(getcfg("3dlut.bt1886_gamma")))
+			self.trc_gamma_ctrl.SetValue(str(getcfg("3dlut.trc_gamma")))
 		else:
-			if str(v) != self.bt1886_gamma_ctrl.GetValue():
-				self.bt1886_gamma_ctrl.SetValue(str(v))
-			setcfg("3dlut.bt1886_gamma", v)
+			if str(v) != self.trc_gamma_ctrl.GetValue():
+				self.trc_gamma_ctrl.SetValue(str(v))
+			setcfg("3dlut.trc_gamma", v)
 			config.writecfg()
+			self.update_trc_control()
 		event.Skip()
 
-	def bt1886_gamma_type_ctrl_handler(self, event):
-		setcfg("3dlut.bt1886_gamma_type",
-			   self.bt1886_gamma_types_ab[self.bt1886_gamma_type_ctrl.GetSelection()])
-		config.writecfg()
+	def trc_ctrl_handler(self, event):
+		if self.trc_ctrl.GetSelection() == 0:
+			# BT.1886
+			setcfg("3dlut.trc_gamma", 2.4)
+			setcfg("3dlut.trc_gamma_type", "B")
+			setcfg("3dlut.trc_output_offset", 0.0)
+			config.writecfg()
+			self.update_trc_controls()
 
-	def input_drop_unsupported_handler(self):
-		self.drop_unsupported("input")
-		
-	def output_drop_unsupported_handler(self):
-		self.drop_unsupported("output")
-	
-	def drop_unsupported(self, which):
-		if not self.worker.is_working():
-			files = getattr(self, "%s_droptarget" % which)._filenames
-			InfoDialog(self, msg=lang.getstr("error.file_type_unsupported") +
-							 "\n\n" + "\n".join(files),
-					   ok=lang.getstr("ok"),
-					   bitmap=geticon(32, "dialog-error"))
+	def trc_gamma_type_ctrl_handler(self, event):
+		setcfg("3dlut.trc_gamma_type",
+			   self.trc_gamma_types_ab[self.trc_gamma_type_ctrl.GetSelection()])
+		config.writecfg()
+		self.update_trc_control()
 
 	def abstract_drop_handler(self, path):
 		if not self.worker.is_working():
@@ -290,11 +328,12 @@ class LUT3DFrame(BaseFrame):
 					 getcfg("3dlut.output.profile.apply_cal"))
 		input_encoding = getcfg("3dlut.encoding.input")
 		output_encoding = getcfg("3dlut.encoding.output")
-		if getcfg("3dlut.apply_bt1886_gamma_mapping"):
-			bt1886_gamma = getcfg("3dlut.bt1886_gamma")
+		if getcfg("3dlut.apply_trc"):
+			trc_gamma = getcfg("3dlut.trc_gamma")
 		else:
-			bt1886_gamma = None
-		bt1886_gamma_type = getcfg("3dlut.bt1886_gamma_type")
+			trc_gamma = None
+		trc_gamma_type = getcfg("3dlut.trc_gamma_type")
+		outoffset = getcfg("3dlut.trc_output_offset")
 		intent = getcfg("3dlut.rendering_intent")
 		format = getcfg("3dlut.format")
 		size = getcfg("3dlut.size")
@@ -308,8 +347,9 @@ class LUT3DFrame(BaseFrame):
 									 output_bits=output_bits,
 									 input_encoding=input_encoding,
 									 output_encoding=output_encoding,
-									 bt1886_gamma=bt1886_gamma,
-									 bt1886_gamma_type=bt1886_gamma_type)
+									 trc_gamma=trc_gamma,
+									 trc_gamma_type=trc_gamma_type,
+									 trc_output_offset=outoffset)
 		except Exception, exception:
 			return exception
 	
@@ -353,7 +393,7 @@ class LUT3DFrame(BaseFrame):
 			self.lut3d_size_ctrl.SetSelection(self.lut3d_size_ba[65])
 		config.writecfg()
 		self.setup_encoding_ctrl(format)
-		self.enable_encoding_controls()
+		self.update_encoding_controls()
 		self.enable_size_controls()
 		self.show_bitdepth_controls()
 		self.lut3d_create_btn.Enable(format != "madVR" or
@@ -436,10 +476,11 @@ class LUT3DFrame(BaseFrame):
 							self.output_profile_desc.Hide()
 							self.apply_cal_cb.Hide()
 							self.show_encoding_controls(False)
-							self.show_bt1886_controls(False)
+							self.show_trc_controls(False)
 							self.rendering_intent_label.Hide()
 							self.rendering_intent_ctrl.Hide()
 							self.panel.GetSizer().Layout()
+							self.update_layout()
 							self.Thaw()
 					else:
 						if which == "input":
@@ -455,9 +496,11 @@ class LUT3DFrame(BaseFrame):
 							self.output_profile_desc.Show()
 							self.apply_cal_cb.Show()
 							self.show_encoding_controls()
-							self.enable_encoding_controls()
-							self.show_bt1886_controls()
-							if ("rTRC" in profile.tags and
+							self.update_encoding_controls()
+							self.show_trc_controls()
+							if (getcfg("3dlut.%s.profile" % which) !=
+								profile.fileName and
+								"rTRC" in profile.tags and
 								"gTRC" in profile.tags and
 								"bTRC" in profile.tags and profile.tags.rTRC is
 								profile.tags.gTRC is profile.tags.bTRC and
@@ -465,17 +508,16 @@ class LUT3DFrame(BaseFrame):
 								# Use BT.1886 gamma mapping for SMPTE 240M /
 								# Rec. 709 TRC
 								tf = profile.tags.rTRC.get_transfer_function()
-								setcfg("3dlut.apply_bt1886_gamma_mapping",
+								setcfg("3dlut.apply_trc",
 									  int(tf[0][1] in (-240, -709)))
-							self.apply_bt1886_cb.SetValue(bool(getcfg("3dlut.apply_bt1886_gamma_mapping")))
-							enable_bt1886_gamma = self.apply_bt1886_cb.GetValue()
-							self.bt1886_gamma_ctrl.Enable(enable_bt1886_gamma)
-							self.bt1886_gamma_type_ctrl.Enable(enable_bt1886_gamma)
+							self.apply_trc_cb.SetValue(bool(getcfg("3dlut.apply_trc")))
+							self.apply_trc_ctrl_handler()
 							self.rendering_intent_label.Show()
 							self.rendering_intent_ctrl.Show()
 							# Update controls related to output profile
 							self.set_profile("output", silent=silent)
 							self.panel.GetSizer().Layout()
+							self.update_layout()
 							self.Thaw()
 						elif which == "output":
 							self.apply_cal_cb.SetValue("vcgt" in profile.tags and
@@ -501,6 +543,7 @@ class LUT3DFrame(BaseFrame):
 			if which == "input":
 				getattr(self, "%s_profile_ctrl" %
 							  which).SetPath(getcfg("3dlut.%s.profile" % which))
+				self.update_encoding_controls()
 			else:
 				getattr(self, "%s_profile_desc" % which).SetLabel("")
 				if not silent:
@@ -513,47 +556,31 @@ class LUT3DFrame(BaseFrame):
 	def setup_language(self):
 		BaseFrame.setup_language(self)
 		
-		# Create the file picker ctrls dynamically to get translated strings
 		for which in ("input", "abstract", "output"):
-			origpickerctrl = self.FindWindowByName("%s_profile_ctrl" % which)
-			hsizer = origpickerctrl.GetContainingSizer()
 			msg = {"input": lang.getstr("3dlut.input.profile"),
 				   "abstract": lang.getstr("3dlut.use_abstract_profile"),
 				   "output": lang.getstr("output.profile")}[which]
 			kwargs = dict(toolTip=msg.rstrip(":"),
 						  dialogTitle=msg,
 						  fileMask=lang.getstr("filetype.icc")
-								   + "|*.icc;*.icm",
-						  changeCallback=getattr(self,
-												 "%s_profile_ctrl_handler" % 
-												 which),
-						  name="%s_profile_ctrl" % which)
-			if which not in ("abstract", "output"):
-				kwargs["history"] = get_data_path("ref", "\.(icc|icm)$")
-			setattr(self, "%s_profile_ctrl" % which,
-					FileBrowse(self.panel, -1, **kwargs))
-			getattr(self, "%s_profile_ctrl" %
-						  which).SetMaxFontSize(11)
-			hsizer.Replace(origpickerctrl,
-						   getattr(self, "%s_profile_ctrl" % which))
-			origpickerctrl.Destroy()
-			hsizer.Layout()
-			# Drop targets
-			setattr(self, "%s_droptarget" % which, FileDrop())
-			getattr(self, "%s_droptarget" % which).drophandlers = {".icc": getattr(self, "%s_drop_handler" % which),
-																   ".icm": getattr(self, "%s_drop_handler" % which)}
-			getattr(self, "%s_droptarget" % which).unsupported_handler = getattr(self, "%s_drop_unsupported_handler" % which)
-			getattr(self, "%s_profile_ctrl"
-						  % which).SetDropTarget(getattr(self, "%s_droptarget"
-														 % which))
+								   + "|*.icc;*.icm")
+			ctrl = getattr(self, "%s_profile_ctrl" % which)
+			for name, value in kwargs.iteritems():
+				setattr(ctrl, name, value)
+
+		items = []
+		for item in ("trc.rec1886", "custom"):
+			items.append(lang.getstr(item))
+		self.trc_ctrl.SetItems(items)
 		
-		self.bt1886_gamma_types_ab = {0: "b", 1: "B"}
-		self.bt1886_gamma_types_ba = {"b": 0, "B": 1}
-		self.bt1886_gamma_type_ctrl.SetItems([lang.getstr("trc.type.relative"),
+		self.trc_gamma_types_ab = {0: "b", 1: "B"}
+		self.trc_gamma_types_ba = {"b": 0, "B": 1}
+		self.trc_gamma_type_ctrl.SetItems([lang.getstr("trc.type.relative"),
 											  lang.getstr("trc.type.absolute")])
 		
 		self.rendering_intents_ab = {}
 		self.rendering_intents_ba = {}
+		self.rendering_intent_ctrl.Clear()
 		for i, ri in enumerate(config.valid_values["3dlut.rendering_intent"]):
 			self.rendering_intent_ctrl.Append(lang.getstr("gamap.intents." + ri))
 			self.rendering_intents_ab[i] = ri
@@ -561,6 +588,7 @@ class LUT3DFrame(BaseFrame):
 		
 		self.lut3d_formats_ab = {}
 		self.lut3d_formats_ba = {}
+		self.lut3d_format_ctrl.Clear()
 		for i, format in enumerate(config.valid_values["3dlut.format"]):
 			if format != "madVR" or self.worker.argyll_version >= [1, 6]:
 				self.lut3d_format_ctrl.Append(lang.getstr("3dlut.format.%s" % format))
@@ -569,6 +597,7 @@ class LUT3DFrame(BaseFrame):
 		
 		self.lut3d_size_ab = {}
 		self.lut3d_size_ba = {}
+		self.lut3d_size_ctrl.Clear()
 		for i, size in enumerate(config.valid_values["3dlut.size"]):
 			self.lut3d_size_ctrl.Append("%sx%sx%s" % ((size, ) * 3))
 			self.lut3d_size_ab[i] = size
@@ -576,6 +605,8 @@ class LUT3DFrame(BaseFrame):
 		
 		self.lut3d_bitdepth_ab = {}
 		self.lut3d_bitdepth_ba = {}
+		self.lut3d_bitdepth_input_ctrl.Clear()
+		self.lut3d_bitdepth_output_ctrl.Clear()
 		for i, bitdepth in enumerate(config.valid_values["3dlut.bitdepth.input"]):
 			self.lut3d_bitdepth_input_ctrl.Append(str(bitdepth))
 			self.lut3d_bitdepth_output_ctrl.Append(str(bitdepth))
@@ -621,8 +652,7 @@ class LUT3DFrame(BaseFrame):
 		self.abstract_profile_ctrl_handler(None)
 		self.output_profile_ctrl.SetPath(getcfg("3dlut.output.profile"))
 		self.output_profile_ctrl_handler(None)
-		self.bt1886_gamma_ctrl.SetValue(str(getcfg("3dlut.bt1886_gamma")))
-		self.bt1886_gamma_type_ctrl.SetSelection(self.bt1886_gamma_types_ba[getcfg("3dlut.bt1886_gamma_type")])
+		self.update_trc_controls()
 		self.rendering_intent_ctrl.SetSelection(self.rendering_intents_ba[getcfg("3dlut.rendering_intent")])
 		format = getcfg("3dlut.format")
 		if format == "madVR" and self.worker.argyll_version < [1, 6]:
@@ -635,6 +665,22 @@ class LUT3DFrame(BaseFrame):
 		self.lut3d_bitdepth_input_ctrl.SetSelection(self.lut3d_bitdepth_ba[getcfg("3dlut.bitdepth.input")])
 		self.lut3d_bitdepth_output_ctrl.SetSelection(self.lut3d_bitdepth_ba[getcfg("3dlut.bitdepth.output")])
 		self.show_bitdepth_controls()
+
+	def update_trc_control(self):
+		if (getcfg("3dlut.trc_gamma_type") == "B" and
+			getcfg("3dlut.trc_output_offset") == 0 and
+			getcfg("3dlut.trc_gamma") == 2.4):
+			self.trc_ctrl.SetSelection(0)  # BT.1886
+		else:
+			self.trc_ctrl.SetSelection(1)  # Gamma
+
+	def update_trc_controls(self):
+		self.update_trc_control()
+		self.trc_gamma_ctrl.SetValue(str(getcfg("3dlut.trc_gamma")))
+		self.trc_gamma_type_ctrl.SetSelection(self.trc_gamma_types_ba[getcfg("3dlut.trc_gamma_type")])
+		outoffset = int(getcfg("3dlut.trc_output_offset") * 100)
+		self.black_output_offset_ctrl.SetValue(outoffset)
+		self.black_output_offset_intctrl.SetValue(outoffset)
 	
 	def show_bitdepth_controls(self):
 		self.Freeze()
@@ -645,13 +691,20 @@ class LUT3DFrame(BaseFrame):
 		self.lut3d_bitdepth_output_label.Show(output_show)
 		self.lut3d_bitdepth_output_ctrl.Show(output_show)
 		self.panel.GetSizer().Layout()
+		self.update_layout()
 		self.Thaw()
 
-	def show_bt1886_controls(self, show=True):
+	def show_trc_controls(self, show=True):
 		show = show and self.worker.argyll_version >= [1, 6]
-		self.apply_bt1886_cb.Show(show)
-		self.bt1886_gamma_ctrl.Show(show)
-		self.bt1886_gamma_type_ctrl.Show(show)
+		self.apply_trc_cb.Show(show)
+		self.trc_ctrl.Show(show)
+		self.trc_gamma_label.Show(show)
+		self.trc_gamma_ctrl.Show(show)
+		self.trc_gamma_type_ctrl.Show(show)
+		self.black_output_offset_label.Show(show)
+		self.black_output_offset_ctrl.Show(show)
+		self.black_output_offset_intctrl.Show(show)
+		self.black_output_offset_intctrl_label.Show(show)
 	
 	def show_encoding_controls(self, show=True):
 		show = show and self.worker.argyll_version >= [1, 6]
@@ -660,7 +713,7 @@ class LUT3DFrame(BaseFrame):
 		self.encoding_output_label.Show(show)
 		self.encoding_output_ctrl.Show(show)
 	
-	def enable_encoding_controls(self):
+	def update_encoding_controls(self):
 		self.encoding_input_ctrl.SetSelection(self.encoding_ba[getcfg("3dlut.encoding.input")])
 		self.encoding_input_ctrl.Enable(getcfg("3dlut.format") != "madVR")
 		if getcfg("3dlut.format") == "eeColor":
