@@ -18,6 +18,7 @@ from util_list import floatlist, strlist
 from util_str import safe_unicode
 from wxaddons import wx
 from wxwindows import ConfirmDialog, InfoDialog, InvincibleFrame
+from wxfixes import GenBitmapButton as BitmapButton
 try:
 	import RealDisplaySizeMM as RDSMM
 except ImportError, exception:
@@ -86,8 +87,8 @@ def get_default_size():
 				# use assumed ppi
 				display_size_mm = (display_size[0] / ppi_def * 25.4, 
 								   display_size[1] / ppi_def * 25.4)
-		display_sizes += [display_size]
-		display_sizes_mm += [display_size_mm]
+		display_sizes.append(display_size)
+		display_sizes_mm.append(display_size_mm)
 	if sum(mm[0] for mm in display_sizes_mm) / \
 				 len(display_sizes_mm) == display_sizes_mm[0][0] and \
 	   sum(mm[1] for mm in display_sizes_mm) / \
@@ -136,27 +137,27 @@ class MeasureFrame(InvincibleFrame):
 		self.sizer.Add(self.hsizer, flag=wx.ALIGN_CENTER_HORIZONTAL | wx.ALL | 
 										 wx.ALIGN_TOP, border=10)
 
-		self.zoommaxbutton = wx.BitmapButton(self.panel, -1, 
-											 geticon(32, "zoom-best-fit"), 
-											 style=wx.NO_BORDER)
+		self.zoommaxbutton = BitmapButton(self.panel, -1, 
+										  geticon(32, "zoom-best-fit"), 
+										  style=wx.NO_BORDER)
 		self.Bind(wx.EVT_BUTTON, self.zoommax_handler, self.zoommaxbutton)
 		self.hsizer.Add(self.zoommaxbutton, flag=wx.ALIGN_CENTER)
 		self.zoommaxbutton.SetToolTipString(lang.getstr("measureframe.zoommax"))
 
 		self.hsizer.Add((2, 1))
 
-		self.zoominbutton = wx.BitmapButton(self.panel, -1, 
-											geticon(32, "zoom-in"), 
-											style=wx.NO_BORDER)
+		self.zoominbutton = BitmapButton(self.panel, -1, 
+										 geticon(32, "zoom-in"), 
+										 style=wx.NO_BORDER)
 		self.Bind(wx.EVT_BUTTON, self.zoomin_handler, self.zoominbutton)
 		self.hsizer.Add(self.zoominbutton, flag=wx.ALIGN_CENTER)
 		self.zoominbutton.SetToolTipString(lang.getstr("measureframe.zoomin"))
 
 		self.hsizer.Add((2, 1))
 
-		self.zoomnormalbutton = wx.BitmapButton(self.panel, -1, 
-												geticon(32, "zoom-original"), 
-												style=wx.NO_BORDER)
+		self.zoomnormalbutton = BitmapButton(self.panel, -1, 
+											 geticon(32, "zoom-original"), 
+											 style=wx.NO_BORDER)
 		self.Bind(wx.EVT_BUTTON, self.zoomnormal_handler, self.zoomnormalbutton)
 		self.hsizer.Add(self.zoomnormalbutton, flag=wx.ALIGN_CENTER)
 		self.zoomnormalbutton.SetToolTipString(lang.getstr("measureframe."
@@ -164,16 +165,16 @@ class MeasureFrame(InvincibleFrame):
 
 		self.hsizer.Add((2, 1))
 
-		self.zoomoutbutton = wx.BitmapButton(self.panel, -1, 
-											 geticon(32, "zoom-out"), 
-											 style=wx.NO_BORDER)
+		self.zoomoutbutton = BitmapButton(self.panel, -1, 
+										  geticon(32, "zoom-out"), 
+										  style=wx.NO_BORDER)
 		self.Bind(wx.EVT_BUTTON, self.zoomout_handler, self.zoomoutbutton)
 		self.hsizer.Add(self.zoomoutbutton, flag=wx.ALIGN_CENTER)
 		self.zoomoutbutton.SetToolTipString(lang.getstr("measureframe.zoomout"))
 
-		self.centerbutton = wx.BitmapButton(self.panel, -1, 
-											geticon(32, "window-center"), 
-											style=wx.NO_BORDER)
+		self.centerbutton = BitmapButton(self.panel, -1, 
+										 geticon(32, "window-center"), 
+										 style=wx.NO_BORDER)
 		self.Bind(wx.EVT_BUTTON, self.center_handler, self.centerbutton)
 		self.sizer.Add(self.centerbutton, flag=wx.ALIGN_CENTER | wx.LEFT | 
 											   wx.RIGHT, border=10)
@@ -200,6 +201,8 @@ class MeasureFrame(InvincibleFrame):
 												 wx.ALIGN_CENTER_HORIZONTAL | 
 												 wx.ALL, border=10)
 		self.measurebutton.SetMaxFontSize(11)
+		self.measurebutton.SetDefault()
+		self.measurebutton.SetFocus()
 
 		self.display_no = wx.Display.GetFromWindow(self)
 		self.display_rects = get_display_rects()
@@ -304,6 +307,7 @@ class MeasureFrame(InvincibleFrame):
 		measureframe_min_size = [max(self.sizer.GetMinSize())] * 2
 		if debug: safe_print("[D]  measureframe_min_size:", measureframe_min_size)
 		default_measureframe_size = get_default_size()
+		defaults["size.measureframe"] = default_measureframe_size
 		size = [min(display_client_size[0], 
 								 default_measureframe_size * scale), 
 							 min(display_client_size[1], 
