@@ -18,14 +18,17 @@ from options import debug
 from ordereddict import OrderedDict
 from util_io import GzipFileProper
 from util_os import launch_file, make_win32_compatible_long_path, waccess
-from util_str import safe_unicode, universal_newlines, wrap
-from worker import (Error, UnloggedError, check_set_argyll_bin, get_argyll_util,
-					make_argyll_compatible_path, show_result_dialog)
+from util_str import safe_unicode, strtr, universal_newlines, wrap
+from worker import (Error, UnloggedError, UnloggedInfo, check_set_argyll_bin,
+					get_argyll_util, make_argyll_compatible_path,
+					show_result_dialog)
 from wxaddons import get_platform_window_decoration_size, wx
 from wxLUTViewer import LUTCanvas, LUTFrame
 from wxVRML2X3D import vrmlfile2x3dfile
-from wxwindows import (BitmapBackgroundPanelText, ConfirmDialog,
+from wxwindows import (BitmapBackgroundPanelText, CustomCheckBox, CustomGrid,
+					   CustomRowLabelRenderer, ConfirmDialog,
 					   FileDrop, InfoDialog, SimpleBook, TwoWaySplitter)
+from wxfixes import GenBitmapButton as BitmapButton
 import colormath
 import config
 import wxenhancedplot as plot
@@ -38,12 +41,8 @@ FGCOLOUR = "#999999"
 TEXTCOLOUR = "#333333"
 
 if sys.platform == "darwin":
-	FONTSIZE_LARGE = 11
-	FONTSIZE_MEDIUM = 11
 	FONTSIZE_SMALL = 10
 else:
-	FONTSIZE_LARGE = 10
-	FONTSIZE_MEDIUM = 8
 	FONTSIZE_SMALL = 8
 
 
@@ -75,144 +74,195 @@ class GamutCanvas(LUTCanvas):
 		poly._attributes["width"] = 3
 		polys = []
 
-		# Very rough (in a*b*)
-		optimalcolors = [(102, -131),
-						 (119, -134),
-						 (128, -133),
-						 (127, -123),
-						 (124, -118),
-						 (114, -108),
-						 (115, -94),
-						 (116, -77),
-						 (114, -63),
-						 (110, -46),
-						 (104, -27),
-						 (97, -1),
-						 (92, 32),
-						 (90, 53),
-						 (89, 73),
-						 (88, 90),
-						 (84, 102),
-						 (75, 114),
-						 (64, 124),
-						 (50, 133),
-						 (35, 141),
-						 (17, 145),
-						 (-6, 140),
-						 (-46, 129),
-						 (-81, 116),
-						 (-113, 97),
-						 (-144, 68),
-						 (-160, 39),
-						 (-163, 26),
-						 (-162, 16),
-						 (-155, 4),
-						 (-135, -12),
-						 (-89, -46),
-						 (-58, -67),
-						 (-29, -83),
-						 (17, -103),
-						 (67, -121),
-						 (102, -131)]
+		# L*a*b*
+		optimalcolors = [(52.40, 95.40, 10.58),
+						 (52.33, 91.23, 38.56),
+						 (52.31, 89.09, 65.80),
+						 (52.30, 88.24, 89.93),
+						 (59.11, 84.13, 101.46),
+						 (66.02, 75.66, 113.09),
+						 (72.36, 64.33, 123.65),
+						 (78.27, 50.88, 132.94),
+						 (83.64, 36.33, 140.63),
+						 (88.22, 22.05, 145.02),
+						 (92.09, 8.49, 143.95),
+						 (90.38, -4.04, 141.05),
+						 (87.54, -23.02, 136.16),
+						 (85.18, -37.06, 132.16),
+						 (82.10, -52.65, 126.97),
+						 (85.53, -65.59, 122.51),
+						 (82.01, -81.46, 116.55),
+						 (77.35, -97.06, 108.72),
+						 (74.76, -122.57, 90.91),
+						 (68.33, -134.27, 80.11),
+						 (63.07, -152.99, 56.41),
+						 (54.57, -159.74, 42.75),
+						 (44.43, -162.58, 27.45),
+						 (46.92, -162.26, 13.87),
+						 (48.53, -144.04, -4.73),
+						 (49.50, -115.82, -25.38),
+						 (59.18, -85.50, -47.00),
+						 (59.33, -68.64, -58.79),
+						 (59.41, -52.73, -69.57),
+						 (50.80, -25.33, -84.08),
+						 (42.05, 8.67, -98.57),
+						 (33.79, 43.74, -111.63),
+						 (26.63, 74.31, -121.90),
+						 (20.61, 98.44, -128.77),
+						 (14.87, 117.34, -131.97),
+						 (9.74, 127.16, -129.59),
+						 (5.20, 125.79, -120.43),
+						 (7.59, 122.01, -116.33),
+						 (10.21, 117.89, -111.81),
+						 (26.35, 115.11, -100.95),
+						 (40.68, 115.59, -87.47),
+						 (39.37, 115.48, -78.51),
+						 (46.49, 114.84, -66.24),
+						 (53.49, 111.63, -54.17),
+						 (52.93, 107.54, -38.16),
+						 (52.58, 101.53, -16.45),
+						 (52.40, 95.40, 10.58)]
+
+		# CIE 1931 2-deg chromaticity coordinates
+		# http://www.cvrl.org/offercsvccs.php
+		xy = [(0.175560, 0.005294),
+			  (0.175161, 0.005256),
+			  (0.174821, 0.005221),
+			  (0.174510, 0.005182),
+			  (0.174112, 0.004964),
+			  (0.174008, 0.004981),
+			  (0.173801, 0.004915),
+			  (0.173560, 0.004923),
+			  (0.173337, 0.004797),
+			  (0.173021, 0.004775),
+			  (0.172577, 0.004799),
+			  (0.172087, 0.004833),
+			  (0.171407, 0.005102),
+			  (0.170301, 0.005789),
+			  (0.168878, 0.006900),
+			  (0.166895, 0.008556),
+			  (0.164412, 0.010858),
+			  (0.161105, 0.013793),
+			  (0.156641, 0.017705),
+			  (0.150985, 0.022740),
+			  (0.143960, 0.029703),
+			  (0.135503, 0.039879),
+			  (0.124118, 0.057803),
+			  (0.109594, 0.086843),
+			  (0.091294, 0.132702),
+			  (0.068706, 0.200723),
+			  (0.045391, 0.294976),
+			  (0.023460, 0.412703),
+			  (0.008168, 0.538423),
+			  (0.003859, 0.654823),
+			  (0.013870, 0.750186),
+			  (0.038852, 0.812016),
+			  (0.074302, 0.833803),
+			  (0.114161, 0.826207),
+			  (0.154722, 0.805864),
+			  (0.192876, 0.781629),
+			  (0.229620, 0.754329),
+			  (0.265775, 0.724324),
+			  (0.301604, 0.692308),
+			  (0.337363, 0.658848),
+			  (0.373102, 0.624451),
+			  (0.408736, 0.589607),
+			  (0.444062, 0.554714),
+			  (0.478775, 0.520202),
+			  (0.512486, 0.486591),
+			  (0.544787, 0.454434),
+			  (0.575151, 0.424232),
+			  (0.602933, 0.396497),
+			  (0.627037, 0.372491),
+			  (0.648233, 0.351395),
+			  (0.665764, 0.334011),
+			  (0.680079, 0.319747),
+			  (0.691504, 0.308342),
+			  (0.700606, 0.299301),
+			  (0.707918, 0.292027),
+			  (0.714032, 0.285929),
+			  (0.719033, 0.280935),
+			  (0.723032, 0.276948),
+			  (0.725992, 0.274008),
+			  (0.728272, 0.271728),
+			  (0.729969, 0.270031),
+			  (0.731089, 0.268911),
+			  (0.731993, 0.268007),
+			  (0.732719, 0.267281),
+			  (0.733417, 0.266583),
+			  (0.734047, 0.265953),
+			  (0.734390, 0.265610),
+			  (0.734592, 0.265408),
+			  (0.734690, 0.265310),
+			  (0.734690, 0.265310),
+			  (0.734690, 0.265310),
+			  (0.734548, 0.265452),
+			  (0.734690, 0.265310),
+			  (0.734690, 0.265310),
+			  (0.734690, 0.265310),
+			  (0.734690, 0.265310),
+			  (0.734690, 0.265310),
+			  (0.734690, 0.265310),
+			  (0.734690, 0.265310),
+			  (0.734690, 0.265310),
+			  (0.734690, 0.265310),
+			  (0.734690, 0.265310),
+			  (0.734690, 0.265310),
+			  (0.734690, 0.265310),
+			  (0.734690, 0.265310),
+			  (0.734690, 0.265310),
+			  (0.734690, 0.265310),
+			  (0.734690, 0.265310),
+			  (0.734690, 0.265310),
+			  (0.734690, 0.265310),
+			  (0.734690, 0.265310),
+			  (0.734690, 0.265310),
+			  (0.734690, 0.265310),
+			  (0.734690, 0.265310),
+			  (0.734690, 0.265310)]
 
 		if self.colorspace == "xy":
-			self.spec_x = 8
-			self.spec_y = 8
 			label_x = "x"
 			label_y = "y"
 			if show_outline:
-				polys.append(plot.PolySpline([(0.173, 0.003),
-											  (0.165, 0.010),
-											  (0.157, 0.017),
-											  (0.144, 0.029),
-											  (0.135, 0.039),
-											  (0.124, 0.057),
-											  (0.109, 0.086),
-											  (0.090, 0.131),
-											  (0.068, 0.200),
-											  (0.045, 0.295),
-											  (0.023, 0.413),
-											  (0.007, 0.538),
-											  (0.003, 0.655),
-											  (0.013, 0.750),
-											  (0.039, 0.814),
-											  (0.074, 0.835),
-											  (0.115, 0.827),
-											  (0.156, 0.807),
-											  (0.194, 0.783),
-											  (0.230, 0.755),
-											  (0.266, 0.725),
-											  (0.303, 0.693),
-											  (0.338, 0.660),
-											  (0.374, 0.626),
-											  (0.513, 0.488),
-											  (0.740, 0.260)],
+				polys.append(plot.PolySpline(xy,
 											 colour=wx.Colour(102, 102, 102, 153),
 											 width=1.75))
-				polys.append(plot.PolyLine([(0.173, 0.003), (0.740, 0.260)],
+				polys.append(plot.PolyLine([xy[0], xy[-1]],
 										   colour=wx.Colour(102, 102, 102, 153),
 										   width=1.75))
-			max_x = 0.84
-			max_y = 0.84
-			min_x = 0
-			min_y = 0
+			max_x = 0.75
+			max_y = 0.85
+			min_x = -.05
+			min_y = -.05
 			step = .1
 		elif self.colorspace == "u'v'":
-			self.spec_x = 6
-			self.spec_y = 6
 			label_x = "u'"
 			label_y = "v'"
 			if show_outline:
-				polys.append(plot.PolySpline([(0.260, 0.018),
-											  (0.254, 0.016),
-											  (0.232, 0.038),
-											  (0.213, 0.059),
-											  (0.186, 0.090),
-											  (0.142, 0.154),
-											  (0.082, 0.272),
-											  (0.028, 0.410),
-											  (0.005, 0.501),
-											  (0.001, 0.543),
-											  (0.002, 0.559),
-											  (0.006, 0.570),
-											  (0.012, 0.577),
-											  (0.021, 0.583),
-											  (0.036, 0.586),
-											  (0.052, 0.587),
-											  (0.081, 0.586),
-											  (0.115, 0.582),
-											  (0.156, 0.577),
-											  (0.207, 0.569),
-											  (0.264, 0.561),
-											  (0.334, 0.550),
-											  (0.408, 0.539),
-											  (0.472, 0.530),
-											  (0.624, 0.507)],
+				uv = [colormath.xyY2Lu_v_(x, y, 100)[1:] for x, y in xy]
+				polys.append(plot.PolySpline(uv,
 											 colour=wx.Colour(102, 102, 102, 153),
 											 width=1.75))
-				polys.append(plot.PolyLine([(0.260, 0.018), (0.624, 0.507)],
+				polys.append(plot.PolyLine([uv[0], uv[-1]],
 										   colour=wx.Colour(102, 102, 102, 153),
 										   width=1.75))
-			max_x = 0.6
+			max_x = 0.625
 			max_y = 0.6
-			min_x = 0
-			min_y = 0
+			min_x = -.025
+			min_y = -.025
 			step = .1
 		elif self.colorspace == "u*v*":
-			# Not used, hard to present gamut projection appropriately in 2D
+			# Hard to present gamut projection appropriately in 2D
 			# because blue tones 'cave in' towards the center
-			self.spec_x = 8
-			self.spec_y = 8
 			label_x = "u*"
 			label_y = "v*"
-			max_x = 50.0
-			max_y = 50.0
-			min_x = -50.0
-			min_y = -50.0
+			max_x = 150.0
+			max_y = 150.0
+			min_x = -150.0
+			min_y = -150.0
 			step = 50
 		elif self.colorspace == "DIN99":
-			self.spec_x = 8
-			self.spec_y = 8
 			label_x = "a99"
 			label_y = "b99"
 			max_x = 50.0
@@ -221,8 +271,6 @@ class GamutCanvas(LUTCanvas):
 			min_y = -50.0
 			step = 25
 		elif self.colorspace in ("DIN99b", "DIN99c", "DIN99d"):
-			self.spec_x = 8
-			self.spec_y = 8
 			if self.colorspace == "DIN99c":
 				label_x = "a99c"
 				label_y = "b99c"
@@ -235,14 +283,12 @@ class GamutCanvas(LUTCanvas):
 			min_y = -65.0
 			step = 25
 		else:
-			self.spec_x = 8
-			self.spec_y = 8
 			label_x = "a*"
 			label_y = "b*"
-			max_x = 130.0
-			max_y = 146.0
-			min_x = -166.0
-			min_y = -136.0
+			max_x = 150.0
+			max_y = 150.0
+			min_x = -150.0
+			min_y = -150.0
 			step = 50
 		
 		convert2coords = {"a*b*": lambda X, Y, Z: colormath.XYZ2Lab(*[v * 100 for v in X, Y, Z])[1:],
@@ -254,10 +300,14 @@ class GamutCanvas(LUTCanvas):
 						  "DIN99c": lambda X, Y, Z: colormath.XYZ2DIN99c(*[v * 100 for v in X, Y, Z])[1:],
 						  "DIN99d": lambda X, Y, Z: colormath.XYZ2DIN99d(*[v * 100 for v in X, Y, Z])[1:]}[self.colorspace]
 
-		if show_outline and self.colorspace in ("a*b*", "DIN99", "DIN99b",
-												"DIN99c", "DIN99d"):
-			polys.append(plot.PolySpline([convert2coords(*colormath.Lab2XYZ(0, a, b))
-										  for a, b in optimalcolors],
+		if show_outline and (self.colorspace == "a*b*" or
+							 self.colorspace.startswith("DIN99")):
+			if self.colorspace == "a*b*":
+				optimalcolors = [Lab[1:] for Lab in optimalcolors]
+			else:
+				optimalcolors = [convert2coords(*colormath.Lab2XYZ(L, a, b))
+								 for L, a, b in optimalcolors]
+			polys.append(plot.PolySpline(optimalcolors,
 										 colour=wx.Colour(102, 102, 102, 153),
 										 width=1.75))
 		
@@ -364,27 +414,31 @@ class GamutCanvas(LUTCanvas):
 										 size=s,
 										 marker=marker,
 										 width=w))
-		
-		max_abs_x = max(abs(min_x), max_x)
-		max_abs_y = max(abs(min_y), max_y)
 
+		xy_range = max(abs(min_x), abs(min_y)) + max(max_x, max_y)
 		if center:
 			self.axis_x = self.axis_y = (min(min_x, min_y), max(max_x, max_y))
-			self.center_x = 0 + (min_x + max_x) / 2
-			self.center_y = 0 + (min_y + max_y) / 2
-		self.ratio = [max(max_abs_x, max_abs_y) /
-					  max(max_abs_x, max_abs_y)] * 2
-		if colorspace == "ab" or colorspace.startswith("DIN99"):
-			ab_range = max(abs(min_x), abs(min_y)) + max(max_x, max_y)
-			self.spec_x = ab_range / step
-			self.spec_y = ab_range / step
+			self.spec_x = xy_range / step
+			self.spec_y = xy_range / step
 
 		if polys:
-			self._DrawCanvas(plot.PlotGraphics(polys, title, label_x, label_y))
+			graphics = plot.PlotGraphics(polys, title, label_x, label_y)
+			p1, p2 = graphics.boundingBox()
+			spacer = plot.PolyMarker([(p1[0] - xy_range / 20.0,
+									   p1[1] - xy_range / 20.0),
+									  (p2[0] + xy_range / 20.0,
+									   p2[1] + xy_range / 20.0)],
+									  colour=wx.Colour(0x33, 0x33, 0x33),
+									  size=0)
+			graphics.objects.append(spacer)
+			if center:
+				boundingbox = spacer.boundingBox()
+				self.resetzoom(boundingbox)
+				self.center(boundingbox)
+			self._DrawCanvas(graphics)
 	
 	def reset(self):
 		self.axis_x = self.axis_y = -128, 128
-		self.ratio = 1.0, 1.0
 
 	def set_pcs_data(self, i):
 		if len(self.pcs_data) < i + 1:
@@ -657,7 +711,7 @@ class GamutViewOptions(wx.Panel):
 		# Colorspace outline
 		self.options_sizer.Add((0, 0))
 		self.options_sizer.Add((0, 0))
-		self.draw_gamut_outline_cb = wx.CheckBox(self, -1,
+		self.draw_gamut_outline_cb = CustomCheckBox(self, -1,
 												 lang.getstr("colorspace.show_outline"))
 		self.draw_gamut_outline_cb.Bind(wx.EVT_CHECKBOX,
 										self.draw_gamut_outline_handler)
@@ -724,9 +778,9 @@ class GamutViewOptions(wx.Panel):
 							   flag=wx.ALIGN_CENTER_VERTICAL)
 		self.comparison_profile_select.Bind(wx.EVT_CHOICE,
 											self.comparison_profile_select_handler)
-		droptarget = FileDrop({".icc": self.comparison_profile_drop_handler,
-							   ".icm": self.comparison_profile_drop_handler},
-							  parent=self.TopLevelParent)
+		droptarget = FileDrop(self.TopLevelParent,
+							  {".icc": self.comparison_profile_drop_handler,
+							   ".icm": self.comparison_profile_drop_handler})
 		self.comparison_profile_select.SetDropTarget(droptarget)
 		if srgb:
 			self.comparison_profile_select.SetSelection(1)
@@ -755,11 +809,12 @@ class GamutViewOptions(wx.Panel):
 		self.options_sizer.Add((0, 0))
 		
 		# LUT toggle
-		self.toggle_clut = wx.CheckBox(self, -1, "LUT")
+		self.toggle_clut = CustomCheckBox(self, -1, "LUT")
 		self.toggle_clut.SetForegroundColour(FGCOLOUR)
 		self.toggle_clut.SetMaxFontSize(11)
 		self.options_sizer.Add(self.toggle_clut, flag=wx.ALIGN_CENTER_VERTICAL)
 		self.toggle_clut.Bind(wx.EVT_CHECKBOX, self.toggle_clut_handler)
+		self.toggle_clut.Hide()
 		
 		# Direction selection
 		self.direction_select = wx.Choice(self, -1,
@@ -770,6 +825,7 @@ class GamutViewOptions(wx.Panel):
 							   flag=wx.ALIGN_CENTER_VERTICAL)
 		self.direction_select.Bind(wx.EVT_CHOICE, self.direction_select_handler)
 		self.direction_select.SetSelection(0)
+		self.direction_select.Hide()
 
 		self.sizer.Add((0, 0))
 
@@ -884,7 +940,8 @@ class GamutViewOptions(wx.Panel):
 	def order(self):
 		parent = self.TopLevelParent
 		return {True: "n",
-				False: "r"}.get(not ("B2A0" in parent.profile.tags or
+				False: "r"}.get(bool(parent.profile) and 
+								not ("B2A0" in parent.profile.tags or
 									 "A2B0" in parent.profile.tags) or
 								self.toggle_clut.GetValue())
 
@@ -897,7 +954,8 @@ class GamutViewOptions(wx.Panel):
 	def toggle_clut_handler(self, event):
 		parent = self.TopLevelParent
 		self.Freeze()
-		self.direction_select.Show("B2A0" in parent.profile.tags and
+		self.direction_select.Show(bool(parent.profile) and 
+								   "B2A0" in parent.profile.tags and
 								   "A2B0" in parent.profile.tags and
 								   self.toggle_clut.GetValue())
 		self.DrawCanvas(reset=False)
@@ -916,8 +974,6 @@ class ProfileInfoFrame(LUTFrame):
 		self.SetIcons(config.get_icon_bundle([256, 48, 32, 16],
 											 appname + "-profile-info"))
 		
-		self.CreateStatusBar(1)
-		
 		self.profile = None
 		self.xLabel = lang.getstr("in")
 		self.yLabel = lang.getstr("out")
@@ -925,27 +981,10 @@ class ProfileInfoFrame(LUTFrame):
 		self.sizer = wx.BoxSizer(wx.VERTICAL)
 		self.SetSizer(self.sizer)
 		
-		self.title_panel = BitmapBackgroundPanelText(self)
-		self.title_panel.SetForegroundColour(TEXTCOLOUR)
-		self.title_panel.SetBitmap(getbitmap("theme/gradient"))
-		self.sizer.Add(self.title_panel, flag=wx.EXPAND)
-		
-		self.title_sizer = wx.BoxSizer(wx.HORIZONTAL)
-		self.title_panel.SetSizer(self.title_sizer)
-		
-		self.title_txt = self.title_panel
-		font = wx.Font(FONTSIZE_LARGE, wx.FONTFAMILY_DEFAULT, wx.FONTSTYLE_NORMAL, 
-					   wx.FONTWEIGHT_NORMAL)
-		self.title_txt.SetFont(font)
-		self.title_sizer.Add((0, 32))
-		
-		gridbgcolor = wx.Colour(234, 234, 234)
-		
 		self.splitter = TwoWaySplitter(self, -1, agwStyle = wx.SP_LIVE_UPDATE | wx.SP_NOSASH)
-		self.splitter.SetBackgroundColour(wx.Colour(204, 204, 204))
 		self.sizer.Add(self.splitter, 1, flag=wx.EXPAND)
 		
-		p1 = wx.Panel(self.splitter)
+		p1 = wx.Panel(self.splitter, name="canvaspanel")
 		p1.SetBackgroundColour(BGCOLOUR)
 		p1.sizer = wx.BoxSizer(wx.VERTICAL)
 		p1.SetSizer(p1.sizer)
@@ -962,50 +1001,53 @@ class ProfileInfoFrame(LUTFrame):
 		self.plot_mode_select = wx.Choice(p1, -1, choices=[lang.getstr("vcgt"),
 														   lang.getstr("[rgb]TRC"),
 														   lang.getstr("gamut")])
-		self.plot_mode_sizer.Add(self.plot_mode_select, flag=wx.ALIGN_CENTER_VERTICAL |
-															 wx.LEFT, border=20)
+		self.plot_mode_sizer.Add(self.plot_mode_select,
+								 flag=wx.ALIGN_CENTER_VERTICAL)
 		self.plot_mode_select.Bind(wx.EVT_CHOICE, self.plot_mode_select_handler)
 		self.plot_mode_select.SetSelection(2)
 		self.plot_mode_select.Disable()
 		
-		self.tooltip_btn = wx.StaticBitmap(p1, -1, geticon(16, "dialog-information"),
-										   style=wx.NO_BORDER)
+		self.tooltip_btn = BitmapButton(p1, -1, geticon(16, "dialog-information"),
+										style=wx.NO_BORDER)
 		self.tooltip_btn.SetBackgroundColour(BGCOLOUR)
+		self.tooltip_btn.Bind(wx.EVT_BUTTON, self.tooltip_handler)
 		self.tooltip_btn.SetToolTipString(lang.getstr("gamut_plot.tooltip"))
 		self.plot_mode_sizer.Add(self.tooltip_btn, flag=wx.ALIGN_CENTER_VERTICAL |
 														wx.LEFT, border=8)
 
-		self.save_plot_btn = wx.BitmapButton(p1, -1,
-											 geticon(16, "media-floppy"),
-											 style=wx.NO_BORDER)
+		self.save_plot_btn = BitmapButton(p1, -1,
+										  geticon(16, "camera-photo"),
+										  style=wx.NO_BORDER)
 		self.save_plot_btn.SetBackgroundColour(BGCOLOUR)
 		self.save_plot_btn.Bind(wx.EVT_BUTTON, self.SaveFile)
-		self.save_plot_btn.SetToolTipString(lang.getstr("save_as"))
-		self.save_plot_btn.SetBitmapDisabled(geticon(16, "empty"))
+		self.save_plot_btn.SetToolTipString(lang.getstr("save_as") + " " +
+											"(*.bmp, *.xbm, *.xpm, *.jpg, *.png)")
 		self.save_plot_btn.Disable()
 		self.plot_mode_sizer.Add(self.save_plot_btn, flag=wx.ALIGN_CENTER_VERTICAL |
 														  wx.LEFT, border=8)
 		
-		self.view_3d_btn = wx.BitmapButton(p1, -1, geticon(16, "3D"),
-										   style=wx.NO_BORDER)
+		self.view_3d_btn = BitmapButton(p1, -1, geticon(16, "3D"),
+										style=wx.NO_BORDER)
 		self.view_3d_btn.SetBackgroundColour(BGCOLOUR)
 		self.view_3d_btn.Bind(wx.EVT_BUTTON, self.view_3d)
+		self.view_3d_btn.Bind(wx.EVT_CONTEXT_MENU, self.view_3d_format_popup)
 		self.view_3d_btn.SetToolTipString(lang.getstr("view.3d"))
-		self.view_3d_btn.SetBitmapDisabled(geticon(16, "empty"))
 		self.view_3d_btn.Disable()
 		self.plot_mode_sizer.Add(self.view_3d_btn, flag=wx.ALIGN_CENTER_VERTICAL |
 														wx.LEFT, border=12)
-		self.view_3d_format_ctrl = wx.Choice(p1, -1, choices=["HTML",
-															  "VRML",
-															  "X3D"])
-		self.view_3d_format_ctrl.SetStringSelection(getcfg("3d.format"))
-		self.view_3d_format_ctrl.Bind(wx.EVT_CHOICE,
-									  lambda event:
-									  setcfg("3d.format",
-											 event.GetEventObject().GetStringSelection()))
-		self.plot_mode_sizer.Add(self.view_3d_format_ctrl,
+		self.view_3d_format_btn = BitmapButton(p1, -1,
+											   getbitmap("theme/dropdown-arrow"),
+											   style=wx.NO_BORDER)
+		self.view_3d_format_btn.MinSize = (-1, self.view_3d_btn.Size[1])
+		self.view_3d_format_btn.SetBackgroundColour(BGCOLOUR)
+		self.view_3d_format_btn.Bind(wx.EVT_BUTTON, self.view_3d_format_popup)
+		self.view_3d_format_btn.Bind(wx.EVT_CONTEXT_MENU,
+									 self.view_3d_format_popup)
+		self.view_3d_format_btn.SetToolTipString(lang.getstr("view.3d"))
+		self.view_3d_format_btn.Disable()
+		self.plot_mode_sizer.Add(self.view_3d_format_btn,
 								 flag=wx.ALIGN_CENTER_VERTICAL | wx.LEFT,
-								 border=8)
+								 border=4)
 
 		self.client = GamutCanvas(p1)
 		p1.sizer.Add(self.client, 1, flag=wx.EXPAND | wx.LEFT | wx.RIGHT |
@@ -1013,14 +1055,24 @@ class ProfileInfoFrame(LUTFrame):
 		
 		self.options_panel = SimpleBook(p1)
 		self.options_panel.SetBackgroundColour(BGCOLOUR)
-		p1.sizer.Add(self.options_panel, flag=wx.EXPAND | wx.BOTTOM, border=12)
+		p1.sizer.Add(self.options_panel, flag=wx.EXPAND | wx.BOTTOM, border=8)
+		
+		self.status = BitmapBackgroundPanelText(p1)
+		self.status.SetMaxFontSize(11)
+		h = self.status.GetTextExtent("Ig")[1]
+		self.status.SetMinSize((0, h * 2 + 10))
+		self.status.label_y = 0
+		self.status.textshadow = False
+		self.status.SetBackgroundColour(BGCOLOUR)
+		self.status.SetForegroundColour(FGCOLOUR)
+		p1.sizer.Add(self.status, flag=wx.EXPAND)
 		
 		# Gamut view options
 		self.gamut_view_options = GamutViewOptions(p1)
 		self.options_panel.AddPage(self.gamut_view_options, "")
 		
 		# Curve view options
-		self.lut_view_options = wx.Panel(p1)
+		self.lut_view_options = wx.Panel(p1, name="lut_view_options")
 		self.lut_view_options.SetBackgroundColour(BGCOLOUR)
 		self.lut_view_options_sizer = self.box_sizer = wx.FlexGridSizer(0, 3, 4, 4)
 		self.lut_view_options_sizer.AddGrowableCol(0)
@@ -1040,8 +1092,8 @@ class ProfileInfoFrame(LUTFrame):
 														  lang.getstr("gamap.intents.r"),
 														  lang.getstr("gamap.intents.p"),
 														  lang.getstr("gamap.intents.s")])
-		hsizer.Add(self.rendering_intent_select, flag=wx.ALIGN_CENTER_VERTICAL | wx.LEFT,
-				   border=10)
+		hsizer.Add((10, self.rendering_intent_select.Size[1]))
+		hsizer.Add(self.rendering_intent_select, flag=wx.ALIGN_CENTER_VERTICAL)
 		self.rendering_intent_select.Bind(wx.EVT_CHOICE,
 										  self.rendering_intent_select_handler)
 		self.rendering_intent_select.SetSelection(1)
@@ -1064,81 +1116,84 @@ class ProfileInfoFrame(LUTFrame):
 		
 		hsizer.Add((16, 0))
 		
-		self.show_as_L = wx.CheckBox(self.lut_view_options, -1, u"L* \u2192")
+		self.show_as_L = CustomCheckBox(self.lut_view_options, -1, u"L* \u2192")
 		self.show_as_L.SetForegroundColour(FGCOLOUR)
 		self.show_as_L.SetValue(True)
-		hsizer.Add(self.show_as_L,
-										flag=wx.ALIGN_CENTER_VERTICAL)
-		self.Bind(wx.EVT_CHECKBOX, self.DrawLUT, id=self.show_as_L.GetId())
+		hsizer.Add(self.show_as_L, flag=wx.ALIGN_CENTER_VERTICAL | wx.RIGHT,
+				   border=4)
+		self.show_as_L.Bind(wx.EVT_CHECKBOX, self.DrawLUT)
 		
-		self.toggle_red = wx.CheckBox(self.lut_view_options, -1, "R")
+		self.toggle_red = CustomCheckBox(self.lut_view_options, -1, "R")
 		self.toggle_red.SetForegroundColour(FGCOLOUR)
 		self.toggle_red.SetValue(True)
 		hsizer.Add(self.toggle_red,
 										flag=wx.ALIGN_CENTER_VERTICAL)
-		self.Bind(wx.EVT_CHECKBOX, self.DrawLUT, id=self.toggle_red.GetId())
+		self.toggle_red.Bind(wx.EVT_CHECKBOX, self.DrawLUT)
 		
-		self.toggle_green = wx.CheckBox(self.lut_view_options, -1, "G")
+		hsizer.Add((4, 0))
+		
+		self.toggle_green = CustomCheckBox(self.lut_view_options, -1, "G")
 		self.toggle_green.SetForegroundColour(FGCOLOUR)
 		self.toggle_green.SetValue(True)
 		hsizer.Add(self.toggle_green,
 										flag=wx.ALIGN_CENTER_VERTICAL)
-		self.Bind(wx.EVT_CHECKBOX, self.DrawLUT, id=self.toggle_green.GetId())
+		self.toggle_green.Bind(wx.EVT_CHECKBOX, self.DrawLUT)
 		
-		self.toggle_blue = wx.CheckBox(self.lut_view_options, -1, "B")
+		hsizer.Add((4, 0))
+		
+		self.toggle_blue = CustomCheckBox(self.lut_view_options, -1, "B")
 		self.toggle_blue.SetForegroundColour(FGCOLOUR)
 		self.toggle_blue.SetValue(True)
 		hsizer.Add(self.toggle_blue,
 										flag=wx.ALIGN_CENTER_VERTICAL)
-		self.Bind(wx.EVT_CHECKBOX, self.DrawLUT, id=self.toggle_blue.GetId())
+		self.toggle_blue.Bind(wx.EVT_CHECKBOX, self.DrawLUT)
 		
-		self.toggle_clut = wx.CheckBox(self.lut_view_options, -1, "LUT")
+		self.toggle_clut = CustomCheckBox(self.lut_view_options, -1, "LUT")
 		self.toggle_clut.SetForegroundColour(FGCOLOUR)
 		hsizer.Add(self.toggle_clut, flag=wx.ALIGN_CENTER_VERTICAL |
 												   wx.LEFT, border=16)
-		self.Bind(wx.EVT_CHECKBOX, self.toggle_clut_handler,
-				  id=self.toggle_clut.GetId())
+		self.toggle_clut.Bind(wx.EVT_CHECKBOX, self.toggle_clut_handler)
 		
 		self.lut_view_options_sizer.Add((0, 0))
 		
-		p2 = wx.Panel(self.splitter)
-		p2.SetBackgroundColour(gridbgcolor)
+		p2 = wx.Panel(self.splitter, name="gridpanel")
 		p2.sizer = wx.BoxSizer(wx.VERTICAL)
 		p2.SetSizer(p2.sizer)
 		self.splitter.AppendWindow(p2)
 		
-		self.grid = ProfileInfoGrid(p2, -1)
+		self.grid = CustomGrid(p2, -1)
+		self.grid.alternate_row_label_background_color = wx.Colour(230, 230, 230)
+		self.grid.alternate_cell_background_color = self.grid.alternate_row_label_background_color
+		self.grid.draw_horizontal_grid_lines = False
+		self.grid.draw_vertical_grid_lines = False
+		self.grid.draw_row_labels = False
+		self.grid.show_cursor_outline = False
+		self.grid.style = ""
 		self.grid.CreateGrid(0, 2)
-		self.grid.SetCellHighlightColour(gridbgcolor)
 		self.grid.SetCellHighlightPenWidth(0)
 		self.grid.SetCellHighlightROPenWidth(0)
-		self.grid.SetDefaultCellBackgroundColour(gridbgcolor)
-		self.grid.SetDefaultCellTextColour(TEXTCOLOUR)
-		font = wx.Font(FONTSIZE_MEDIUM, wx.FONTFAMILY_DEFAULT, wx.FONTSTYLE_NORMAL, 
-					   wx.FONTWEIGHT_NORMAL)
-		self.grid.SetDefaultCellFont(font)
-		self.grid.SetDefaultRowSize(20)
-		self.grid.SetLabelBackgroundColour(gridbgcolor)
-		self.grid.SetRowLabelSize(20)
+		self.grid.SetDefaultCellBackgroundColour(self.grid.GetLabelBackgroundColour())
+		font = self.grid.GetDefaultCellFont()
+		if font.PointSize > 11:
+			font.PointSize = 11
+			self.grid.SetDefaultCellFont(font)
+		self.grid.SetSelectionMode(wx.grid.Grid.wxGridSelectRows)
+		self.grid.SetRowLabelSize(self.grid.GetDefaultRowSize())
 		self.grid.SetColLabelSize(0)
 		self.grid.DisableDragRowSize()
 		self.grid.EnableDragColSize()
 		self.grid.EnableEditing(False)
 		self.grid.EnableGridLines(False)
 		self.grid.Bind(wx.grid.EVT_GRID_COL_SIZE, self.resize_grid)
-		p2.sizer.Add(self.grid, 1, flag=wx.EXPAND, border=12)
+		p2.sizer.Add(self.grid, 1, flag=wx.EXPAND)
 		
 		drophandlers = {
 			".icc": self.drop_handler,
 			".icm": self.drop_handler
 		}
-		droptarget = FileDrop(drophandlers, parent=self)
-		self.title_panel.SetDropTarget(droptarget)
-		droptarget = FileDrop(drophandlers, parent=self)
-		self.title_txt.SetDropTarget(droptarget)
-		droptarget = FileDrop(drophandlers, parent=self)
+		droptarget = FileDrop(self, drophandlers)
 		self.client.SetDropTarget(droptarget)
-		droptarget = FileDrop(drophandlers, parent=self)
+		droptarget = FileDrop(self, drophandlers)
 		self.grid.SetDropTarget(droptarget)
 
 		self.splitter.SetMinimumPaneSize(defaults["size.profile_info.w"] - self.splitter._GetSashSize())
@@ -1172,22 +1227,27 @@ class ProfileInfoFrame(LUTFrame):
 				child.SetMaxFontSize(11)
 			child.Bind(wx.EVT_KEY_DOWN, self.key_handler)
 			child.Bind(wx.EVT_MOUSEWHEEL, self.OnWheel)
+			if (sys.platform == "win32" and sys.getwindowsversion() >= (6, ) and
+				isinstance(child, wx.Panel)):
+				# No need to enable double buffering under Linux and Mac OS X.
+				# Under Windows, enabling double buffering on the panel seems
+				# to work best to reduce flicker.
+				child.SetDoubleBuffered(True)
 
 	def DrawCanvas(self, profile_no=None, reset=True):
 		self.SetStatusText('')
 		if self.plot_mode_select.GetSelection() == self.plot_mode_select.GetCount() - 1:
 			# Gamut plot
-			self.plot_mode_sizer.Show(self.tooltip_btn)
 			self.plot_mode_sizer.Show(self.view_3d_btn)
-			self.plot_mode_sizer.Show(self.view_3d_format_ctrl)
+			self.plot_mode_sizer.Show(self.view_3d_format_btn)
 			self.options_panel.GetCurrentPage().DrawCanvas(reset=reset)
 			self.save_plot_btn.Enable()
 			self.view_3d_btn.Enable()
+			self.view_3d_format_btn.Enable()
 		else:
 			# Curves plot
-			self.plot_mode_sizer.Hide(self.tooltip_btn)
 			self.plot_mode_sizer.Hide(self.view_3d_btn)
-			self.plot_mode_sizer.Hide(self.view_3d_format_ctrl)
+			self.plot_mode_sizer.Hide(self.view_3d_format_btn)
 			self.client.SetEnableCenterLines(True)
 			self.client.SetEnableDiagonals('Bottomleft-Topright')
 			self.client.SetEnableGrid(False)
@@ -1219,6 +1279,7 @@ class ProfileInfoFrame(LUTFrame):
 			except (IOError, ICCP.ICCProfileInvalidError), exception:
 				show_result_dialog(Error(lang.getstr("profile.invalid") + 
 									     "\n" + profile), self)
+				self.DrawCanvas(reset=reset)
 				return
 		self.profile = profile
 		self.rTRC = profile.tags.get("rTRC")
@@ -1270,16 +1331,8 @@ class ProfileInfoFrame(LUTFrame):
 		self.select_current_page()
 		self.plot_mode_select.Enable()
 		
-		self.title_txt.SetLabel(profile.getDescription())
-		border, titlebar = get_platform_window_decoration_size()
-		titlewidth = self.title_txt.GetTextExtent(self.title_txt.GetLabel())[0] + 30
-		if titlewidth + border * 2 > self.GetMinSize()[0]:
-			self.SetMinSize((titlewidth + border * 2,
-							 defaults["size.profile_info.h"] + titlebar + border))
-			if titlewidth + border * 2 > self.GetSize()[0]:
-				self.SetSize((self.get_platform_window_size()[0],
-							  self.GetSize()[1]))
-				self.splitter.SetExpandedSize(self.get_platform_window_size())
+		self.SetTitle(u" \u2014 ".join([lang.getstr("profile.info"),
+										profile.getDescription()]))
 		
 		rows = [("", "")]
 		lines = []
@@ -1297,19 +1350,27 @@ class ProfileInfoFrame(LUTFrame):
 		for i, line in enumerate(lines):
 			line = list(line)
 			indent = re.match("\s+", line[0])
+			for j, v in enumerate(line):
+				if v.endswith("_"):
+					continue
+				key = re.sub("[^0-9A-Za-z]+", "_",
+							 strtr(line[j],
+								   {u"\u0394E": "Delta E"}).lower().strip(), 0).strip("_")
+				val = lang.getstr(key)
+				if key != val:
+					line[j] = val
 			if indent:
 				#if i + 1 < len(lines) and lines[i + 1][0].startswith(" "):
 					#marker = u" ├  "
 				#else:
 					#marker = u" └  "
-				line[0] = indent.group() + lang.getstr(line[0].strip())
+				line[0] = indent.group() + line[0].strip()
 			elif line[0]:
 				#if i + 1 < len(lines) and lines[i + 1][0].startswith(" "):
 					#marker = u"▼ "
 				#else:
 					#marker = u"► "
-				line[0] = lang.getstr(line[0])
-			line[1] = lang.getstr(line[1])
+				pass
 			rows.append(line)
 		
 		rows.append(("", ""))
@@ -1317,15 +1378,21 @@ class ProfileInfoFrame(LUTFrame):
 		if self.grid.GetNumberRows():
 			self.grid.DeleteRows(0, self.grid.GetNumberRows())
 		self.grid.AppendRows(len(rows))
-		labelcolor = wx.Colour(0x80, 0x80, 0x80)
-		altcolor = wx.Colour(230, 230, 230)
+		labelcolor = self.grid.GetLabelTextColour()
+		alpha = 102
 		namedcolor = False
 		for i, (label, value) in enumerate(rows):
 			self.grid.SetCellValue(i, 0, " " + label)
-			if i % 2:
-				self.grid.SetCellBackgroundColour(i, 0, altcolor)
-				self.grid.SetCellBackgroundColour(i, 1, altcolor)
-			if label == lang.getstr(ICCP.tags["ncl2"]):
+			bgcolor = self.grid.GetCellBackgroundColour(i, 0)
+			bgblend = (255 - alpha) / 255.0
+			blend = alpha / 255.0
+			textcolor = wx.Colour(int(round(bgblend * bgcolor.Red() +
+											blend * labelcolor.Red())),
+								  int(round(bgblend * bgcolor.Green() +
+											blend * labelcolor.Green())),
+								  int(round(bgblend * bgcolor.Blue() +
+											blend * labelcolor.Blue())))
+			if label == lang.getstr("named_colors"):
 				namedcolor = True
 			elif label.strip() and label.lstrip() == label:
 				namedcolor = False
@@ -1344,19 +1411,23 @@ class ProfileInfoFrame(LUTFrame):
 												color.groups()[1].strip().split()],
 											  **dict(scale=255))
 				labelbgcolor = wx.Colour(*[int(round(v)) for v in color])
-			else:
-				labelbgcolor = self.grid.GetCellBackgroundColour(i, 0)
-			self.grid.SetRowLabelRenderer(i, ProfileInfoRowLabelRenderer(labelbgcolor))
-			self.grid.SetCellTextColour(i, 0, labelcolor)
+				self.grid.SetRowLabelRenderer(i,
+											  CustomRowLabelRenderer(labelbgcolor))
+			self.grid.SetCellTextColour(i, 0, textcolor)
 			self.grid.SetCellValue(i, 1, value)
 		
 		self.grid.AutoSizeColumn(0)
 		self.resize_grid()
+		self.grid.ClearSelection()
 		self.Layout()
 		self.DrawCanvas(reset=reset)
 		self.Thaw()
 	
 	def OnClose(self, event):
+		if (getattr(self.worker, "thread", None) and
+			self.worker.thread.isAlive()):
+			self.worker.abort_subprocess(True)
+			return
 		self.worker.wrapup(False)
 		event.Skip()
 
@@ -1374,33 +1445,35 @@ class ProfileInfoFrame(LUTFrame):
 					self.client.erase_pointlabel()
 		else:
 			# Gamut plot
-			if self.options_panel.GetCurrentPage().colorspace_select.GetSelection() == 0:
+			page = self.options_panel.GetCurrentPage()
+			if (page.colorspace in ("a*b*", "u*v*") or
+				page.colorspace.startswith("DIN99")):
 				format = "%.2f %.2f"
 			else:
 				format = "%.4f %.4f"
-			page = self.options_panel.GetCurrentPage()
-			colorspace_no = page.colorspace_select.GetSelection()
 			whitepoint_no = page.whitepoint_select.GetSelection()
 			if whitepoint_no > 0:
-				if colorspace_no == 0:
-					# a*b*
+				if page.colorspace == "a*b*":
 					x, y, Y = colormath.Lab2xyY(100.0, xy[0], xy[1])
-				elif colorspace_no == 1:
-					# u' v'
+				elif page.colorspace == "u*v*":
+					X, Y, Z = colormath.Luv2XYZ(100.0, xy[0], xy[1])
+					x, y = colormath.XYZ2xyY(X, Y, Z)[:2]
+				elif page.colorspace == "u'v'":
 					x, y = colormath.u_v_2xy(xy[0], xy[1])
-				elif colorspace_no in (3, 4, 5, 6):
+				elif page.colorspace.startswith("DIN99"):
 					# DIN99
 					L99 = colormath.Lab2DIN99(100, 0, 0)[0]
-					if colorspace_no == 4:
+					if page.colorspace == "DIN99b":
 						# DIN99b
 						a, b = colormath.DIN99b2Lab(L99, xy[0], xy[1])[1:]
-					elif colorspace_no == 5:
+					elif page.colorspace == "DIN99c":
 						# DIN99c
 						a, b = colormath.DIN99c2Lab(L99, xy[0], xy[1])[1:]
-					elif colorspace_no == 6:
+					elif page.colorspace == "DIN99d":
 						# DIN99d
 						a, b = colormath.DIN99d2Lab(L99, xy[0], xy[1])[1:]
 					else:
+						# DIN99
 						a, b = colormath.DIN992Lab(L99, xy[0], xy[1])[1:]
 					x, y = colormath.Lab2xyY(100.0, a, b)[:2]
 				else:
@@ -1547,33 +1620,7 @@ class ProfileInfoFrame(LUTFrame):
 			focus = self.FindFocus()
 			if focus and self.grid in (focus, focus.GetParent(),
 									   focus.GetGrandParent()):
-				if key == 65: # A
-					self.grid.SelectAll()
-					return
-				elif key in (67, 88): # C / X
-					clip = []
-					cells = self.grid.GetSelection()
-					i = -1
-					start_col = self.grid.GetNumberCols()
-					for cell in cells:
-						row = cell[0]
-						col = cell[1]
-						if i < row:
-							clip += [[]]
-							i = row
-						if col < start_col:
-							start_col = col
-						while len(clip[-1]) - 1 < col:
-							clip[-1] += [""]
-						clip[-1][col] = self.grid.GetCellValue(row, col)
-					for i, row in enumerate(clip):
-						clip[i] = "\t".join(row[start_col:])
-					clipdata = wx.TextDataObject()
-					clipdata.SetText("\n".join(clip))
-					wx.TheClipboard.Open()
-					wx.TheClipboard.SetData(clipdata)
-					wx.TheClipboard.Close()
-					return
+				event.Skip()
 			if key == 83 and self.profile: # S
 				self.SaveFile()
 				return
@@ -1651,7 +1698,7 @@ class ProfileInfoFrame(LUTFrame):
 			else:
 				show_result_dialog(Error(lang.getstr("profile.invalid")), self)
 		if profile:
-			view_3d_format = self.view_3d_format_ctrl.GetStringSelection()
+			view_3d_format = getcfg("3d.format")
 			if view_3d_format == "HTML":
 				x3d = True
 				html = True
@@ -1751,7 +1798,7 @@ class ProfileInfoFrame(LUTFrame):
 									  wargs=(profile_paths, intent, direction,
 											 order, False),
 									  progress_msg=lang.getstr("gamut.view.create"),
-									  continue_next=True)
+									  continue_next=x3d)
 	
 	def view_3d_consumer(self, result, colorspace, filename, vrmlpath, x3d,
 						 x3dpath, html):
@@ -1788,74 +1835,26 @@ class ProfileInfoFrame(LUTFrame):
 		else:
 			launch_file(vrmlpath)
 
-class ProfileInfoGrid(wx.grid.Grid):
+	def view_3d_format_popup(self, event):
+		menu = wx.Menu()
 
-	def __init__(self, *args, **kwargs):
-		wx.grid.Grid.__init__(self, *args, **kwargs)
-		self.GetGridRowLabelWindow().Bind(wx.EVT_PAINT, self._onPaintRowLabels)
-		
-		self._rowRenderers = {}
+		item_selected = False
+		for file_format in config.valid_values["3d.format"]:
+			item = menu.AppendRadioItem(-1, file_format)
+			item.Check(file_format == getcfg("3d.format"))
+			self.Bind(wx.EVT_MENU, self.view_3d_format_handler, id=item.Id)
 
-	def _getRowTopBottom(self, row):
-		r = 0
-		top = 0
-		while r < row:
-			top += self.GetRowSize(r)
-			r += 1
-		bottom = top + self.GetRowSize(row) - 1
-		return top, bottom
+		self.PopupMenu(menu)
+		for item in menu.MenuItems:
+			self.Unbind(wx.EVT_MENU, id=item.Id)
+		menu.Destroy()
 
-	def _onPaintRowLabels(self, evt):
-		window = evt.GetEventObject()
-		dc = wx.PaintDC(window)
+	def view_3d_format_handler(self, event):
+		for item in event.EventObject.MenuItems:
+			if item.IsChecked():
+				setcfg("3d.format", item.GetItemLabelText())
 
-		if getattr(self, "CalcRowLabelsExposed", None):
-			# wxPython >= 2.8.10
-			rows = self.CalcRowLabelsExposed(window.GetUpdateRegion())
-			if rows == [-1]:
-				return
-		else:
-			# wxPython < 2.8.10
-			rows = xrange(self.GetNumberRows())
-			if not rows:
-				return
-
-		x, y = self.CalcUnscrolledPosition((0,0))
-		pt = dc.GetDeviceOrigin()
-		dc.SetDeviceOrigin(pt.x, pt.y-y)
-		for row in rows:
-			top, bottom = self._getRowTopBottom(row)
-			rect = wx.Rect()
-			rect.top = top
-			rect.bottom = bottom
-			rect.x = 0
-			rect.width = self.GetRowLabelSize()
-
-			renderer = self._rowRenderers.get(row, None) or \
-					   ProfileInfoRowLabelRenderer(self.GetLabelBackgroundColour(row, 0))
-			renderer.Draw(self, dc, rect, row)
-        
-	def SetRowLabelRenderer(self, row, renderer):
-		"""
-		Register a renderer to be used for drawing the label for the
-		given row.
-		"""
-		if renderer is None:
-			if row in self._rowRenderers:
-				del self._rowRenderers[row]
-		else:
-			self._rowRenderers[row] = renderer
-
-
-class ProfileInfoRowLabelRenderer(object):
-
-	def __init__(self, bgcolor):
-		self._bgcolor = bgcolor
-
-	def Draw(self, grid, dc, rect, row):
-		dc.SetBrush(wx.Brush(self._bgcolor))
-		dc.SetPen(wx.TRANSPARENT_PEN)
-		dc.DrawRectangleRect(rect)
+		self.view_3d(None)
 
 
 class ProfileInfoViewer(wx.App):
