@@ -14,10 +14,8 @@ import config
 import localization as lang
 import worker
 from wxTestchartEditor import TestchartEditor
-from wxaddons import FileDrop
-from wxwindows import (BaseFrame,
-					   FileBrowseBitmapButtonWithChoiceHistory as FileBrowse,
-					   InfoDialog, wx)
+from wxwindows import (BaseFrame, FileDrop, InfoDialog, wx)
+import xh_filebrowsebutton
 
 from wx import xrc
 
@@ -29,6 +27,7 @@ class ReportFrame(BaseFrame):
 	def __init__(self, parent=None):
 		self.res = xrc.XmlResource(get_data_path(os.path.join("xrc", 
 															  "report.xrc")))
+		self.res.InsertHandler(xh_filebrowsebutton.FileBrowseButtonWithHistoryXmlHandler())
 		pre = wx.PreFrame()
 		self.res.LoadOnFrame(pre, parent, "reportframe")
 		self.PostCreate(pre)
@@ -43,21 +42,66 @@ class ReportFrame(BaseFrame):
 		self.worker = worker.Worker(self)
 		self.worker.set_argyll_version("xicclu")
 
+		for which in ("chart", "simulation_profile", "devlink_profile",
+					  "output_profile"):
+			ctrl = self.FindWindowByName("%s_ctrl" % which)
+			setattr(self, "%s_ctrl" % which, ctrl)
+			ctrl.changeCallback = getattr(self, "%s_ctrl_handler" % which)
+			if which not in ("devlink_profile", "output_profile"):
+				if which == "chart":
+					wildcard = "\.(cie|gam|ti1|ti3)$"
+				else:
+					wildcard = "\.(icc|icm)$"
+				if which == "simulation_profile":
+					history = []
+					standard_profiles = config.get_standard_profiles(True)
+					basenames = []
+					for path in standard_profiles:
+						basename = os.path.basename(path)
+						if not basename in basenames:
+							basenames.append(basename)
+							history.append(path)
+				else:
+					history = get_data_path("ref", wildcard)
+				history = sorted(history, key=lambda path:
+											  os.path.basename(path).lower())
+				ctrl.SetHistory(history)
+			ctrl.SetMaxFontSize(11)
+			# Drop targets
+			handler = getattr(self, "%s_drop_handler" % which)
+			if which.endswith("_profile"):
+				drophandlers = {".icc": handler,
+								".icm": handler}
+			else:
+				drophandlers = {".cgats": handler,
+								".cie": handler,
+								".ti1": handler,
+								".ti2": handler,
+								".ti3": handler,
+								".txt": handler}
+			ctrl.SetDropTarget(FileDrop(self, drophandlers))
+
 		# Bind event handlers
 		self.fields_ctrl.Bind(wx.EVT_CHOICE,
 							  self.fields_ctrl_handler)
-		self.chart_btn.SetBitmapDisabled(geticon(16, "empty"))
 		self.chart_btn.Bind(wx.EVT_BUTTON, self.chart_btn_handler)
 		self.simulation_profile_cb.Bind(wx.EVT_CHECKBOX,
 									  self.use_simulation_profile_ctrl_handler)
 		self.use_simulation_profile_as_output_cb.Bind(wx.EVT_CHECKBOX,
 													  self.use_simulation_profile_as_output_handler)
 		self.enable_3dlut_cb.Bind(wx.EVT_CHECKBOX, self.enable_3dlut_handler)
-		self.apply_bt1886_cb.Bind(wx.EVT_CHECKBOX, self.apply_bt1886_ctrl_handler)
-		self.bt1886_gamma_ctrl.Bind(wx.EVT_KILL_FOCUS,
-									self.bt1886_gamma_ctrl_handler)
-		self.bt1886_gamma_type_ctrl.Bind(wx.EVT_CHOICE,
-										 self.bt1886_gamma_type_ctrl_handler)
+		self.apply_trc_cb.Bind(wx.EVT_CHECKBOX, self.apply_trc_ctrl_handler)
+		self.trc_ctrl.Bind(wx.EVT_CHOICE, self.trc_ctrl_handler)
+		self.trc_gamma_ctrl.Bind(wx.EVT_COMBOBOX,
+								 self.trc_gamma_ctrl_handler)
+		self.trc_gamma_ctrl.Bind(wx.EVT_KILL_FOCUS,
+								 self.trc_gamma_ctrl_handler)
+		self.trc_gamma_type_ctrl.Bind(wx.EVT_CHOICE,
+									  self.trc_gamma_type_ctrl_handler)
+		self.black_output_offset_ctrl.Bind(wx.EVT_SLIDER,
+										   self.black_output_offset_ctrl_handler)
+		self.black_output_offset_intctrl.Bind(wx.EVT_TEXT,
+											  self.black_output_offset_ctrl_handler)
 		self.simulate_whitepoint_cb.Bind(wx.EVT_CHECKBOX,
 										 self.simulate_whitepoint_ctrl_handler)
 		self.simulate_whitepoint_relative_cb.Bind(wx.EVT_CHECKBOX,
@@ -100,32 +144,54 @@ class ReportFrame(BaseFrame):
 		if event:
 			event.Skip()
 	
-	def apply_bt1886_ctrl_handler(self, event):
-		v = self.apply_bt1886_cb.GetValue()
-		setcfg("measurement_report.apply_bt1886_gamma_mapping", int(v))
+	def apply_trc_ctrl_handler(self, event):
+		v = self.apply_trc_cb.GetValue()
+		setcfg("measurement_report.apply_trc", int(v))
 		config.writecfg()
 		self.update_main_controls()
 
-	def bt1886_gamma_ctrl_handler(self, event):
+	def black_output_offset_ctrl_handler(self, event):
+		if event.GetId() == self.black_output_offset_intctrl.GetId():
+			self.black_output_offset_ctrl.SetValue(
+				self.black_output_offset_intctrl.GetValue())
+		else:
+			self.black_output_offset_intctrl.SetValue(
+				self.black_output_offset_ctrl.GetValue())
+		v = self.black_output_offset_ctrl.GetValue() / 100.0
+		setcfg("measurement_report.trc_output_offset", v)
+		self.update_trc_control()
+
+	def trc_gamma_ctrl_handler(self, event):
 		try:
-			v = float(self.bt1886_gamma_ctrl.GetValue().replace(",", "."))
-			if (v < config.valid_ranges["measurement_report.bt1886_gamma"][0] or
-				v > config.valid_ranges["measurement_report.bt1886_gamma"][1]):
+			v = float(self.trc_gamma_ctrl.GetValue().replace(",", "."))
+			if (v < config.valid_ranges["measurement_report.trc_gamma"][0] or
+				v > config.valid_ranges["measurement_report.trc_gamma"][1]):
 				raise ValueError()
 		except ValueError:
 			wx.Bell()
-			self.bt1886_gamma_ctrl.SetValue(str(getcfg("measurement_report.bt1886_gamma")))
+			self.trc_gamma_ctrl.SetValue(str(getcfg("measurement_report.trc_gamma")))
 		else:
-			if str(v) != self.bt1886_gamma_ctrl.GetValue():
-				self.bt1886_gamma_ctrl.SetValue(str(v))
-			setcfg("measurement_report.bt1886_gamma", v)
+			if str(v) != self.trc_gamma_ctrl.GetValue():
+				self.trc_gamma_ctrl.SetValue(str(v))
+			setcfg("measurement_report.trc_gamma", v)
 			config.writecfg()
+			self.update_trc_control()
 		event.Skip()
 
-	def bt1886_gamma_type_ctrl_handler(self, event):
-		setcfg("measurement_report.bt1886_gamma_type",
-			   self.bt1886_gamma_types_ab[self.bt1886_gamma_type_ctrl.GetSelection()])
+	def trc_ctrl_handler(self, event):
+		if self.trc_ctrl.GetSelection() == 0:
+			# BT.1886
+			setcfg("measurement_report.trc_gamma", 2.4)
+			setcfg("measurement_report.trc_gamma_type", "B")
+			setcfg("measurement_report.trc_output_offset", 0.0)
+			config.writecfg()
+			self.update_trc_controls()
+
+	def trc_gamma_type_ctrl_handler(self, event):
+		setcfg("measurement_report.trc_gamma_type",
+			   self.trc_gamma_types_ab[self.trc_gamma_type_ctrl.GetSelection()])
 		config.writecfg()
+		self.update_trc_control()
 	
 	def chart_btn_handler(self, event):
 		if self.Parent:
@@ -200,9 +266,6 @@ class ReportFrame(BaseFrame):
 		if not self.worker.is_working():
 			self.chart_ctrl.SetPath(path)
 			self.chart_ctrl_handler(True)
-
-	def chart_drop_unsupported_handler(self):
-		self.drop_unsupported("chart")
 	
 	def devlink_profile_ctrl_handler(self, event):
 		self.set_profile("devlink")
@@ -211,17 +274,6 @@ class ReportFrame(BaseFrame):
 		if not self.worker.is_working():
 			self.devlink_profile_ctrl.SetPath(path)
 			self.set_profile("devlink")
-		
-	def devlink_profile_drop_unsupported_handler(self):
-		self.drop_unsupported("devlink_profile")
-	
-	def drop_unsupported(self, which):
-		if not self.worker.is_working():
-			files = getattr(self, "%s_droptarget" % which)._filenames
-			InfoDialog(self, msg=lang.getstr("error.file_type_unsupported") +
-							 "\n\n" + "\n".join(files),
-					   ok=lang.getstr("ok"),
-					   bitmap=geticon(32, "dialog-error"))
 	
 	def enable_3dlut_handler(self, event):
 		setcfg("3dlut.madVR.enable", int(self.enable_3dlut_cb.GetValue()))
@@ -247,9 +299,6 @@ class ReportFrame(BaseFrame):
 		if not self.worker.is_working():
 			self.output_profile_ctrl.SetPath(path)
 			self.set_profile("output")
-		
-	def output_profile_drop_unsupported_handler(self):
-		self.drop_unsupported("output_profile")
 	
 	def set_profile(self, which, profile_path=None, silent=False):
 		path = getattr(self, "%s_profile_ctrl" % which).GetPath()
@@ -268,7 +317,7 @@ class ReportFrame(BaseFrame):
 				return
 			try:
 				profile = ICCP.ICCProfile(path)
-			except ICCP.ICCProfileInvalidError:
+			except (IOError, ICCP.ICCProfileInvalidError):
 				if not silent:
 					show_result_dialog(Error(lang.getstr("profile.invalid")),
 									   parent=self)
@@ -309,60 +358,31 @@ class ReportFrame(BaseFrame):
 	def setup_language(self):
 		BaseFrame.setup_language(self)
 		
-		# Create the file picker ctrls dynamically to get translated strings
 		for which in ("chart", "simulation_profile", "devlink_profile",
 					  "output_profile"):
-			origpickerctrl = self.FindWindowByName("%s_ctrl" % which)
-			hsizer = origpickerctrl.GetContainingSizer()
 			if which.endswith("_profile"):
 				wildcard = lang.getstr("filetype.icc")  + "|*.icc;*.icm"
 			else:
 				wildcard = (lang.getstr("filetype.ti1_ti3_txt") + 
-							"|*.cgats;*.cie;*.ti1;*.ti2;*.ti3;*.txt")
+							"|*.cgats;*.cie;*.gam;*.ti1;*.ti2;*.ti3;*.txt")
 			msg = {"chart": "measurement_report_choose_chart_or_reference",
+				   "devlink_profile": "devicelink_profile",
 				   "output_profile": "measurement_report_choose_profile"}.get(which, which)
 			kwargs = dict(toolTip=lang.getstr(msg).rstrip(":"),
 						  dialogTitle=lang.getstr(msg), 
-						  fileMask=wildcard,
-						  changeCallback=getattr(self, "%s_ctrl_handler" % 
-													   which),
-						  name="%s_ctrl" % which)
-			if which not in ("devlink_profile", "output_profile"):
-				if which == "chart":
-					wildcard = "\.(cie|ti1|ti3)$"
-				else:
-					wildcard = "\.(icc|icm)$"
-				kwargs["history"] = get_data_path("ref", wildcard)
-			setattr(self, "%s_ctrl" % which,
-					FileBrowse(self.panel, -1, **kwargs))
-			getattr(self, "%s_ctrl" % which).SetMaxFontSize(11)
-			hsizer.Replace(origpickerctrl,
-						   getattr(self, "%s_ctrl" % which))
-			origpickerctrl.Destroy()
-			hsizer.Layout()
-			# Drop targets
-			setattr(self, "%s_droptarget" % which, FileDrop())
-			droptarget = getattr(self, "%s_droptarget" % which)
-			handler = getattr(self, "%s_drop_handler" % which)
-			if which.endswith("_profile"):
-				droptarget.drophandlers = {".icc": handler,
-										   ".icm": handler}
-			else:
-				droptarget.drophandlers = {".cgats": handler,
-										   ".cie": handler,
-										   ".ti1": handler,
-										   ".ti2": handler,
-										   ".ti3": handler,
-										   ".txt": handler}
-			droptarget.unsupported_handler = getattr(self,
-													 "%s_drop_unsupported_handler"
-													 % which)
-			getattr(self, "%s_ctrl"
-						  % which).SetDropTarget(droptarget)
+						  fileMask=wildcard)
+			ctrl = getattr(self, "%s_ctrl" % which)
+			for name, value in kwargs.iteritems():
+				setattr(ctrl, name, value)
+
+		items = []
+		for item in ("trc.rec1886", "custom"):
+			items.append(lang.getstr(item))
+		self.trc_ctrl.SetItems(items)
 		
-		self.bt1886_gamma_types_ab = {0: "b", 1: "B"}
-		self.bt1886_gamma_types_ba = {"b": 0, "B": 1}
-		self.bt1886_gamma_type_ctrl.SetItems([lang.getstr("trc.type.relative"),
+		self.trc_gamma_types_ab = {0: "b", 1: "B"}
+		self.trc_gamma_types_ba = {"b": 0, "B": 1}
+		self.trc_gamma_type_ctrl.SetItems([lang.getstr("trc.type.relative"),
 											  lang.getstr("trc.type.absolute")])
 	
 	def simulate_whitepoint_ctrl_handler(self, event):
@@ -384,21 +404,33 @@ class ReportFrame(BaseFrame):
 		if not self.worker.is_working():
 			self.simulation_profile_ctrl.SetPath(path)
 			self.set_profile("simulation")
-
-	def simulation_profile_drop_unsupported_handler(self):
-		self.drop_unsupported("simulation_profile")
 	
 	def update_controls(self):
 		""" Update controls with values from the configuration """
 		self.simulation_profile_ctrl.SetPath(getcfg("measurement_report.simulation_profile"))
 		self.set_profile("simulation", silent=True)
-		self.bt1886_gamma_ctrl.SetValue(str(getcfg("measurement_report.bt1886_gamma")))
-		self.bt1886_gamma_type_ctrl.SetSelection(self.bt1886_gamma_types_ba[getcfg("measurement_report.bt1886_gamma_type")])
+		self.update_trc_controls()
 		self.devlink_profile_ctrl.SetPath(getcfg("measurement_report.devlink_profile"))
 		self.set_profile("devlink", silent=True)
 		self.output_profile_ctrl.SetPath(getcfg("measurement_report.output_profile"))
 		self.set_profile("output", silent=True)
 		self.set_testchart(getcfg("measurement_report.chart"))
+
+	def update_trc_control(self):
+		if (getcfg("measurement_report.trc_gamma_type") == "B" and
+			getcfg("measurement_report.trc_output_offset") == 0 and
+			getcfg("measurement_report.trc_gamma") == 2.4):
+			self.trc_ctrl.SetSelection(0)  # BT.1886
+		else:
+			self.trc_ctrl.SetSelection(1)  # Gamma
+
+	def update_trc_controls(self):
+		self.update_trc_control()
+		self.trc_gamma_ctrl.SetValue(str(getcfg("measurement_report.trc_gamma")))
+		self.trc_gamma_type_ctrl.SetSelection(self.trc_gamma_types_ba[getcfg("measurement_report.trc_gamma_type")])
+		outoffset = int(getcfg("measurement_report.trc_output_offset") * 100)
+		self.black_output_offset_ctrl.SetValue(outoffset)
+		self.black_output_offset_intctrl.SetValue(outoffset)
 	
 	def set_testchart(self, path):
 		self.chart_ctrl.SetPath(path)
@@ -433,12 +465,18 @@ class ReportFrame(BaseFrame):
 							  ICCP.XYZType) and
 				   isinstance(self.simulation_profile.tags.get("bXYZ"),
 							  ICCP.XYZType))
-		self.apply_bt1886_cb.Enable(enable1 and enable5)
+		self.apply_trc_cb.Enable(enable1 and enable5)
 		enable6 = (enable1 and enable5 and
-				   bool(getcfg("measurement_report.apply_bt1886_gamma_mapping")))
-		self.apply_bt1886_cb.SetValue(enable6)
-		self.bt1886_gamma_ctrl.Enable(enable6)
-		self.bt1886_gamma_type_ctrl.Enable(enable6)
+				   bool(getcfg("measurement_report.apply_trc")))
+		self.apply_trc_cb.SetValue(enable6)
+		self.trc_ctrl.Enable(enable6)
+		self.trc_gamma_label.Enable(enable6)
+		self.trc_gamma_ctrl.Enable(enable6)
+		self.trc_gamma_type_ctrl.Enable(enable6)
+		self.black_output_offset_label.Enable(enable6)
+		self.black_output_offset_ctrl.Enable(enable6)
+		self.black_output_offset_intctrl.Enable(enable6)
+		self.black_output_offset_intctrl_label.Enable(enable6)
 		self.simulate_whitepoint_cb.Enable((enable1 and not enable2) or
 										   (color in ("LAB", "XYZ") and
 											chart_has_white))
@@ -461,15 +499,15 @@ class ReportFrame(BaseFrame):
 		self.output_profile_label.Enable((color in ("LAB", "RGB", "XYZ") or
 										  enable1) and
 										 (not enable1 or not enable2 or
-										 self.apply_bt1886_cb.GetValue()))
+										 self.apply_trc_cb.GetValue()))
 		self.output_profile_ctrl.Enable((color in ("LAB", "RGB", "XYZ") or
 										 enable1) and
 										(not enable1 or not enable2 or
-										self.apply_bt1886_cb.GetValue()))
+										self.apply_trc_cb.GetValue()))
 		self.output_profile_desc.Enable((color in ("LAB", "RGB", "XYZ") or
 										 enable1) and
 										(not enable1 or not enable2 or
-										self.apply_bt1886_cb.GetValue()))
+										self.apply_trc_cb.GetValue()))
 		output_profile = (bool(getcfg("measurement_report.output_profile")) and
 						  os.path.isfile(getcfg("measurement_report.output_profile")))
 		self.measure_btn.Enable(((enable1 and enable2 and (not enable6 or
@@ -484,6 +522,7 @@ class ReportFrame(BaseFrame):
 								  output_profile)) and
 								 bool(getcfg("measurement_report.chart")) and
 								 os.path.isfile(getcfg("measurement_report.chart")))
+		self.update_layout()
 	
 	def use_devlink_profile_ctrl_handler(self, event):
 		setcfg("3dlut.madVR.enable", 0)
@@ -501,6 +540,14 @@ class ReportFrame(BaseFrame):
 			v = int(sim_profile.profileClass == "prtr")
 			setcfg("measurement_report.whitepoint.simulate", v)
 			setcfg("measurement_report.whitepoint.simulate.relative", v)
+			if ("rTRC" in sim_profile.tags and "gTRC" in sim_profile.tags and
+				"bTRC" in sim_profile.tags and sim_profile.tags.rTRC is
+				sim_profile.tags.gTRC is sim_profile.tags.bTRC and
+				isinstance(sim_profile.tags.rTRC, ICCP.CurveType)):
+				# Use BT.1886 gamma mapping for SMPTE 240M / Rec. 709 TRC
+				tf = sim_profile.tags.rTRC.get_transfer_function()
+				setcfg("measurement_report.apply_trc",
+					  int(tf[0][1] in (-240, -709)))
 		config.writecfg()
 		self.update_main_controls()
 
