@@ -6,6 +6,7 @@ Interactive display calibration UI
 
 """
 
+import math
 import os
 import re
 import sys
@@ -18,7 +19,8 @@ from config import (getbitmap, getcfg, geticon, get_data_path, get_icon_bundle,
 from log import get_file_logger, safe_print
 from meta import name as appname
 from options import debug, test, verbose
-from wxwindows import BitmapBackgroundPanel, FlatShadedButton, numpad_keycodes
+from wxwindows import (BitmapBackgroundPanel, CustomCheckBox, CustomGrid,
+					   FlatShadedButton, numpad_keycodes)
 import CGATS
 import colormath
 import config
@@ -27,15 +29,6 @@ import localization as lang
 BGCOLOUR = wx.Colour(0x33, 0x33, 0x33)
 FGCOLOUR = wx.Colour(0x99, 0x99, 0x99)
 
-if sys.platform == "darwin":
-	FONTSIZE_LARGE = 11
-	FONTSIZE_MEDIUM = 11
-	FONTSIZE_SMALL = 10
-else:
-	FONTSIZE_LARGE = 10
-	FONTSIZE_MEDIUM = 8
-	FONTSIZE_SMALL = 8
-
 
 class UntetheredFrame(wx.Frame):
 
@@ -66,13 +59,17 @@ class UntetheredFrame(wx.Frame):
 		self.label_XYZ.SetForegroundColour(FGCOLOUR)
 		panelsizer.Add(self.label_XYZ, 0, wx.TOP | wx.RIGHT | wx.EXPAND,
 					   border=8)
+		if sys.platform == "darwin":
+			style = wx.BORDER_THEME
+		else:
+			style = wx.BORDER_SIMPLE
 		self.panel_RGB = BitmapBackgroundPanel(self.panel, size=(256, 256),
-											   style=wx.BORDER_SIMPLE)
+											   style=style)
 		self.panel_RGB.scalebitmap = (True, True)
 		self.panel_RGB.SetBitmap(getbitmap("theme/checkerboard-32x32x5-333-444"))
 		panelsizer.Add(self.panel_RGB, 1, wx.LEFT | wx.EXPAND, border=8)
 		self.panel_XYZ = BitmapBackgroundPanel(self.panel, size=(256, 256),
-											   style=wx.BORDER_SIMPLE)
+											   style=style)
 		self.panel_XYZ.scalebitmap = (True, True)
 		self.panel_XYZ.SetBitmap(getbitmap("theme/checkerboard-32x32x5-333-444"))
 		panelsizer.Add(self.panel_XYZ, 1, wx.RIGHT | wx.EXPAND, border=8)
@@ -91,7 +88,7 @@ class UntetheredFrame(wx.Frame):
 		self.next_btn.Bind(wx.EVT_BUTTON, self.next_btn_handler)
 		sizer.Add(self.next_btn, 0, wx.LEFT, border=8)
 		sizer.Add((12, 1), 1)
-		self.measure_auto_cb = wx.CheckBox(self.panel, wx.ID_ANY,
+		self.measure_auto_cb = CustomCheckBox(self.panel, wx.ID_ANY,
 										   lang.getstr("auto"))
 		self.measure_auto_cb.SetForegroundColour(FGCOLOUR)
 		self.measure_auto_cb.Bind(wx.EVT_CHECKBOX, self.measure_auto_ctrl_handler)
@@ -130,33 +127,40 @@ class UntetheredFrame(wx.Frame):
 		sizer.Add(self.finish_btn, 0, wx.RIGHT, border=8)
 		panelsizer.Add(sizer, 0, wx.BOTTOM | wx.EXPAND, border=8)
 		
-		self.grid = wx.grid.Grid(self, -1, size=(536, 256))
-		self.grid.CreateGrid(0, 8)
+		self.grid = CustomGrid(self, -1, size=(536, 256))
+		self.grid.DisableDragColSize()
+		self.grid.DisableDragRowSize()
+		self.grid.SetScrollRate(0, 5)
+		self.grid.SetCellHighlightROPenWidth(0)
+		self.grid.SetColLabelSize(self.grid.GetDefaultRowSize())
+		self.grid.SetDefaultCellAlignment(wx.ALIGN_CENTER, wx.ALIGN_CENTER)
+		self.grid.SetRowLabelAlignment(wx.ALIGN_RIGHT, wx.ALIGN_CENTER)
+		self.grid.draw_horizontal_grid_lines = False
+		self.grid.draw_vertical_grid_lines = False
+		self.grid.style = ""
+		self.grid.CreateGrid(0, 9)
 		self.grid.SetRowLabelSize(62)
-		for i in xrange(8):
+		for i in xrange(9):
 			if i in (3, 4):
-				size = 20
+				size = self.grid.GetDefaultRowSize()
+				if i == 4:
+					attr = wx.grid.GridCellAttr()
+					attr.SetBackgroundColour(wx.Colour(0, 0, 0, 0))
+					self.grid.SetColAttr(i, attr)
 			else:
 				size = 62
 			self.grid.SetColSize(i, size)
-		for i, label in enumerate(["R", "G", "B", "", "", "L*", "a*", "b*"]):
+		for i, label in enumerate(["R", "G", "B", "", "", "L*", "a*", "b*", ""]):
 			self.grid.SetColLabelValue(i, label)
-		gridbgcolor = wx.Colour(234, 234, 234)
-		if sys.version_info >= (2, 6):
-			self.grid.SetCellHighlightColour(gridbgcolor)
-			self.grid.SetCellHighlightROPenWidth(0)
 		self.grid.SetCellHighlightPenWidth(0)
-		self.grid.SetDefaultCellBackgroundColour(gridbgcolor)
-		self.grid.SetDefaultCellTextColour(BGCOLOUR)
-		font = wx.Font(FONTSIZE_MEDIUM, wx.FONTFAMILY_DEFAULT, wx.FONTSTYLE_NORMAL, 
-					   wx.FONTWEIGHT_NORMAL)
-		self.grid.SetDefaultCellFont(font)
-		self.grid.SetDefaultRowSize(20)
-		self.grid.SetLabelBackgroundColour(gridbgcolor)
+		self.grid.SetDefaultCellBackgroundColour(self.grid.GetLabelBackgroundColour())
+		font = self.grid.GetDefaultCellFont()
+		if font.PointSize > 11:
+			font.PointSize = 11
+			self.grid.SetDefaultCellFont(font)
 		self.grid.SetSelectionMode(wx.grid.Grid.wxGridSelectRows)
-		self.grid.EnableDragColSize()
 		self.grid.EnableEditing(False)
-		self.grid.EnableGridLines(True)
+		self.grid.EnableGridLines(False)
 		self.grid.Bind(wx.grid.EVT_GRID_LABEL_LEFT_CLICK,
 					   self.grid_left_click_handler)
 		self.grid.Bind(wx.grid.EVT_GRID_CELL_LEFT_CLICK,
@@ -178,7 +182,7 @@ class UntetheredFrame(wx.Frame):
 			accels = []
 			for id, keycode in self.id_to_keycode.iteritems():
 				self.Bind(wx.EVT_MENU, self.key_handler, id=id)
-				accels += [(wx.ACCEL_NORMAL, keycode, id)]
+				accels.append((wx.ACCEL_NORMAL, keycode, id))
 			self.SetAcceleratorTable(wx.AcceleratorTable(accels))
 		else:
 			self.Bind(wx.EVT_CHAR_HOOK, self.key_handler)
@@ -188,12 +192,20 @@ class UntetheredFrame(wx.Frame):
 		# Event handlers
 		self.Bind(wx.EVT_CLOSE, self.OnClose, self)
 		self.Bind(wx.EVT_MOVE, self.OnMove, self)
+		self.Bind(wx.EVT_SIZE, self.OnResize, self)
 		self.timer = wx.Timer(self)
 		if handler:
 			self.Bind(wx.EVT_TIMER, handler, self.timer)
 		self.Bind(wx.EVT_WINDOW_DESTROY, self.OnDestroy, self)
 		
 		# Final initialization steps
+		for child in self.GetAllChildren():
+			if (sys.platform == "win32" and sys.getwindowsversion() >= (6, ) and
+				isinstance(child, wx.Panel)):
+				# No need to enable double buffering under Linux and Mac OS X.
+				# Under Windows, enabling double buffering on the panel seems
+				# to work best to reduce flicker.
+				child.SetDoubleBuffered(True)
 		self.logger = get_file_logger("untethered")
 		self._setup()
 		
@@ -230,6 +242,10 @@ class UntetheredFrame(wx.Frame):
 				setcfg("position.progress.x", x)
 				setcfg("position.progress.y", y)
 
+	def OnResize(self, event):
+		wx.CallAfter(self.resize_grid)
+		event.Skip()
+
 	def Pulse(self, msg=""):
 		if msg == lang.getstr("instrument.initializing"):
 			self.label_RGB.SetLabel(msg)
@@ -255,6 +271,7 @@ class UntetheredFrame(wx.Frame):
 		self.measure_btn._bitmap = geticon(10, {True: "play",
 												False: "pause"}.get(enable))
 		self.measure_btn.Enable(enable or enable_measure_button)
+		self.measure_btn.SetDefault()
 	
 	def finish_btn_handler(self, event):
 		self.finish_btn.Disable()
@@ -318,7 +335,10 @@ class UntetheredFrame(wx.Frame):
 			if row == -1 and col > -1: # col label clicked
 				pass
 			elif row > -1: # row clicked
-				self.update(row)
+				if not (event.CmdDown() or event.ControlDown() or
+						event.ShiftDown()):
+					self.update(row)
+				event.Skip()
 	
 	def has_worker_subprocess(self):
 		return bool(getattr(self, "worker", None) and
@@ -337,34 +357,7 @@ class UntetheredFrame(wx.Frame):
 			keycode = self.id_to_keycode.get(event.GetId())
 		if keycode is not None:
 			if event.GetEventType() == wx.EVT_KEY_DOWN.typeId:
-				if event.ControlDown() or event.CmdDown():
-					# CTRL (Linux/Mac/Windows) / CMD (Mac)
-					if keycode == 65: # A
-						self.grid.SelectAll()
-					elif keycode in (67, 88): # C / X
-						clip = []
-						cells = self.grid.GetSelection()
-						i = -1
-						start_col = self.grid.GetNumberCols()
-						for cell in cells:
-							row = cell[0]
-							col = cell[1]
-							if i < row:
-								clip += [[]]
-								i = row
-							if col < start_col:
-								start_col = col
-							while len(clip[-1]) - 1 < col:
-								clip[-1] += [""]
-							clip[-1][col] = self.grid.GetCellValue(row, col)
-						for i, row in enumerate(clip):
-							clip[i] = "\t".join(row[start_col:])
-						clipdata = wx.TextDataObject()
-						clipdata.SetText("\n".join(clip))
-						wx.TheClipboard.Open()
-						wx.TheClipboard.SetData(clipdata)
-						wx.TheClipboard.Close()
-				elif keycode in (wx.WXK_UP, wx.WXK_NUMPAD_UP):
+				if keycode in (wx.WXK_UP, wx.WXK_NUMPAD_UP):
 					self.back_btn_handler(None)
 				elif keycode in (wx.WXK_DOWN, wx.WXK_NUMPAD_DOWN):
 					self.next_btn_handler(None)
@@ -382,6 +375,8 @@ class UntetheredFrame(wx.Frame):
 					if self.index > -1:
 						self.grid.MovePageUp()
 						self.update(self.grid.GetGridCursorRow())
+				elif event.ControlDown() or event.CmdDown():
+					event.Skip()
 				return
 			elif self.has_worker_subprocess() and keycode < 255:
 				if keycode == 27 or chr(keycode) == "Q":
@@ -558,6 +553,26 @@ class UntetheredFrame(wx.Frame):
 	
 	def reset(self):
 		self._setup()
+
+	def resize_grid(self):
+		num_cols = self.grid.GetNumberCols()
+		if not num_cols:
+			return
+		grid_w = self.grid.GetSize()[0] - self.grid.GetDefaultRowSize() * 2
+		col_w = round(grid_w / (num_cols - 1))
+		last_col_w = grid_w - col_w * (num_cols - 2)
+		self.grid.SetRowLabelSize(col_w)
+		for i in xrange(num_cols):
+			if i in (3, 4):
+				w = self.grid.GetDefaultRowSize()
+			elif i == num_cols - 1:
+				w = last_col_w - wx.SystemSettings_GetMetric(wx.SYS_VSCROLL_X)
+			else:
+				w = col_w
+			self.grid.SetColSize(i, w)
+		self.grid.SetMargins(0 - wx.SystemSettings_GetMetric(wx.SYS_VSCROLL_X),
+							 0)
+		self.grid.ForceRefresh()
 	
 	def _setup(self):
 		self.logger.info("-" * 80)
