@@ -2,6 +2,7 @@
 
 import os
 import sys
+import types
 
 from wxfixes import wx
 
@@ -23,15 +24,17 @@ def GetRealClientArea(self):
 wx.Display.GetRealClientArea = GetRealClientArea
 
 
-def GetAllChildren(self):
+def GetAllChildren(self, skip=None):
 	""" Get children of window and its subwindows """
-	children = self.GetChildren()
+	if not isinstance(skip, (list, tuple)):
+		skip = [skip]
+	children = filter(lambda child: child not in skip, self.GetChildren())
 	allchildren = []
 	for child in children:
-		allchildren += [child]
-		if hasattr(child, "GetAllChildren") and hasattr(child.GetAllChildren, 
+		allchildren.append(child)
+		if hasattr(child, "GetAllChildren") and hasattr(child.GetAllChildren,
 														"__call__"):
-			allchildren += child.GetAllChildren()
+			allchildren += child.GetAllChildren(skip)
 	return allchildren
 
 wx.Window.GetAllChildren = GetAllChildren
@@ -67,13 +70,15 @@ def SetSaneGeometry(self, x=None, y=None, w=None, h=None):
 	# is completely outside the client area of all displays
 	display_client_rect = self.GetDisplay().ClientArea 
 	if sys.platform not in ("darwin", "win32"): # Linux
-		safety_margin = 45
+		safety_margin = 40
 	else:
 		safety_margin = 20
 	if not None in (w, h):
 		# Set given size, but resize if needed to fit inside client area
-		self.SetSize((min(display_client_rect[2] - safety_margin, w), 
-			min(display_client_rect[3] - safety_margin, h))) 
+		min_w, min_h = self.MinSize
+		self.SetSize((max(min(display_client_rect[2], w), min_w), 
+					  max(min(display_client_rect[3] - safety_margin, h),
+						  min_h)))
 	if not None in (x, y):
 		if not display_client_rect.ContainsXY(x, y) or \
 		   not display_client_rect.ContainsRect((x, y, 100, 100)):
@@ -92,18 +97,17 @@ def GridGetSelectedRowsFromSelection(self):
 	by chosing individual cells.
 	
 	"""
-	sel = self.GetSelection()
 	numcols = self.GetNumberCols()
 	rows = []
 	i = -1
-	for cell in sel:
+	for cell in self.GetSelection():
 		row, col = cell
 		if row > i:
 			i = row
 			rownumcols = 0
 		rownumcols += 1
 		if rownumcols == numcols:
-			rows += [row]
+			rows.append(row)
 	return rows
 
 wx.grid.Grid.GetSelectedRowsFromSelection = GridGetSelectedRowsFromSelection
@@ -113,14 +117,12 @@ def GridGetSelectionRows(self):
 	"""
 	Return the selected rows, even if not all cells in a row are selected.
 	"""
-	sel = self.GetSelection()
 	rows = []
 	i = -1
-	for cell in sel:
-		row, col = cell
+	for row, col in self.GetSelection():
 		if row > i:
 			i = row
-			rows += [row]
+			rows.append(row)
 	return rows
 
 wx.grid.Grid.GetSelectionRows = GridGetSelectionRows
@@ -133,21 +135,9 @@ def IsSizer(self):
 wx.Window.IsSizer = IsSizer
 
 
-wx.BitmapButton._SetBitmapDisabled = wx.BitmapButton.SetBitmapDisabled
-
-def SetBitmapDisabled(self, bitmap=None):
-	image = self.GetBitmapLabel().ConvertToImage()
-	if image.HasMask():
-		image.InitAlpha()
-	if image.HasAlpha():
-		alphabuffer = image.GetAlphaBuffer()
-		for i, byte in enumerate(alphabuffer):
-			if byte > "\0":
-				alphabuffer[i] = chr(int(round(ord(byte) * .3)))
-		bitmap = image.ConvertToBitmap()
-	self._SetBitmapDisabled(bitmap)
-
-wx.BitmapButton.SetBitmapDisabled = SetBitmapDisabled
+def adjust_font_size_for_gcdc(font):
+	font.SetPointSize(get_gcdc_font_size(font.PointSize))
+	return font
 
 
 def get_dc_font_size(size, dc):
@@ -155,13 +145,24 @@ def get_dc_font_size(size, dc):
 	pointsize = (1.0, 1.0)
 	if isinstance(dc, wx.GCDC):
 		pointsize = tuple(1.0 / scale for scale in dc.GetLogicalScale())
-	if sys.platform in ("darwin", "win32") or not isinstance(dc, wx.GCDC):
+	if (sys.platform in ("darwin", "win32") or not isinstance(dc, wx.GCDC) or
+		wx.VERSION >= (2, 9)):
 		return size * (sum(pointsize) / 2.0)
 	else:
 		# On Linux, we need to correct the font size by a certain factor if
 		# wx.GCDC is used, to make text the same size as if wx.GCDC weren't used
+		screenppi = map(float, wx.ScreenDC().GetPPI())
 		ppi = dc.GetPPI()
-		return size * ((96.0 / ppi[0] * pointsize[0] + 96.0 / ppi[1] * pointsize[1]) / 2.0)
+		return size * ((screenppi[0] / ppi[0] * pointsize[0] + screenppi[1] / ppi[1] * pointsize[1]) / 2.0)
+
+
+def get_gcdc_font_size(size):
+	dc = wx.MemoryDC(wx.EmptyBitmap(1, 1))
+	try:
+		dc = wx.GCDC(dc)
+	except:
+		pass
+	return get_dc_font_size(size, dc)
 
 
 def get_platform_window_decoration_size():
@@ -199,6 +200,71 @@ class CustomEvent(wx.PyEvent):
 		return self.window
 
 
+class BetterWindowDisabler(object):
+	
+	""" Also disables child windows instead of only top level windows. This is
+	actually needed under Mac OS X where disabling a top level window will
+	not prevent interaction with its children. """
+
+	def __init__(self, skip=None):
+		self._windows = []
+		if skip:
+			if not isinstance(skip, (list, tuple)):
+				skip = [skip]
+		self.skip = skip
+		self.id = id(self)
+		self.disable()
+
+	def __del__(self):
+		self.enable()
+		
+	def disable(self):
+		self.enable(False)
+	
+	def enable(self, enable=True):
+		if not enable:
+			skip = self.skip
+			toplevel = list(wx.GetTopLevelWindows())
+			for w in toplevel:
+				if w not in skip and "Inspection" not in "%s" % w:
+					self._windows.append(w)
+					for child in w.GetAllChildren(skip + toplevel):
+						if (isinstance(child, wx.StaticText) and
+							sys.platform == "darwin"):
+							# wxMac seems to loose foreground color of StaticText
+							# when enabled again
+							continue
+						if child:
+							self._windows.append(child)
+			def Enable(w, enable=True):
+				w._enabled = enable
+			def Disable(w):
+				w._enabled = False
+			for w in reversed(self._windows):
+				if hasattr(w, "_disabler_id"):
+					continue
+				w._disabler_id = self.id
+				enabled = w.IsEnabled()
+				w.Disable()
+				w._Disable = w.Disable
+				w.Disable = types.MethodType(Disable, w, type(w))
+				w._Enable = w.Enable
+				w.Enable = types.MethodType(Enable, w, type(w))
+				w.Enable(enabled)
+			return
+		for w in self._windows:
+			if w:
+				if getattr(w, "_disabler_id", None) != self.id:
+					continue
+				if hasattr(w, "_Disable"):
+					w.Disable = w._Disable
+				if hasattr(w, "_Enable"):
+					w.Enable = w._Enable
+				if hasattr(w, "_enabled"):
+					w.Enable(w._enabled)
+				del w._disabler_id
+
+
 class CustomGridCellEvent(CustomEvent):
 	def __init__(self, typeId, object, row=-1, col=-1, window=None):
 		CustomEvent.__init__(self, typeId, object, window)
@@ -240,6 +306,6 @@ class FileDrop(wx.FileDropTarget):
 
 		if len(self._files):
 			for key in self._files:
-				self.drophandlers[key](self._files[key])
+				wx.CallAfter(self.drophandlers[key], self._files[key])
 		elif self.unsupported_handler:
-			self.unsupported_handler()
+			wx.CallAfter(self.unsupported_handler)
