@@ -749,7 +749,7 @@ class PlotCanvas(wx.Panel):
                 self.pageSetupData.SetMarginBottomRight(data.GetMarginBottomRight())
                 self.pageSetupData.SetMarginTopLeft(data.GetMarginTopLeft())
                 self.pageSetupData.SetPrintData(data.GetPrintData())
-                self.print_data=wx.PrintData(data.GetPrintData()) # updates print_data
+                self._print_data=wx.PrintData(data.GetPrintData()) # updates print_data
         finally:
             dlg.Destroy()
                 
@@ -762,7 +762,7 @@ class PlotCanvas(wx.Panel):
         out = PlotPrintout(self)
         print_ok = printer.Print(self.parent, out)
         if print_ok:
-            self.print_data = wx.PrintData(printer.GetPrintDialogData().GetPrintData())
+            self._print_data = wx.PrintData(printer.GetPrintDialogData().GetPrintData())
         out.Destroy()
 
     def PrintPreview(self):
@@ -1485,11 +1485,11 @@ class PlotCanvas(wx.Panel):
             if evt.GetOrientation() == wx.VERTICAL:
                 fullrange,pagesize = self.sb_vert.GetRange(),self.sb_vert.GetPageSize()
                 sbpos = fullrange-pagesize-sbpos
-                dist = sbpos*self._sb_yunit-(self._getYCurrentRange()[0]-self._sb_yfullrange[0])
+                dist = sbpos*self._sb_yunit-(self._getYCurrentRange()[0]-self._sb_yfullrange)
                 self.ScrollUp(dist)
             
             if evt.GetOrientation() == wx.HORIZONTAL:
-                dist = sbpos*self._sb_xunit-(self._getXCurrentRange()[0]-self._sb_xfullrange[0])
+                dist = sbpos*self._sb_xunit-(self._getXCurrentRange()[0]-self._sb_xfullrange)
                 self.ScrollRight(dist)
                
     # Private Methods **************************************************
@@ -1534,6 +1534,7 @@ class PlotCanvas(wx.Panel):
         dcs.EndDrawing()
 
         dc = wx.ClientDC( self.canvas )
+        dc = wx.BufferedDC(dc, self._Buffer)
         #this will erase if called twice
         dc.Blit(0, 0, width, height, dcs, 0, 0, self._logicalFunction)
         if sys.platform == "darwin":
@@ -1815,12 +1816,17 @@ class PlotCanvas(wx.Panel):
             grid = factor * 10.**power
         if self._useScientificNotation and (power > 4 or power < -4):
             format = '%+7.1e'        
-        elif power >= 0:
-            digits = max(1, int(power))
-            format = '%' + `digits`+'.0f'
         else:
-            digits = -int(power)
-            format = '%'+`digits+2`+'.'+`digits`+'f'
+            if ideal > int(ideal):
+                fdigits = len(str(round(ideal, 4)).split('.')[-1][:4].rstrip('0'))
+            else:
+                fdigits = 0
+            if power >= 0:
+                digits = max(1, int(power))
+                format = '%' + `digits`+'.'+`fdigits`+'f'
+            else:
+                digits = -int(power)
+                format = '%'+`digits+2`+'.'+`fdigits`+'f'
         ticks = []
         t = -grid*_Numeric.floor(-lower/grid)
         while t <= upper:
