@@ -16,6 +16,8 @@ ls -l -G -h --color=always --group-directories-first -R $HOME/.local/lib*/python
 
 ls -l -G -h --color=always $HOME/.local/share/applications/dispcalGUI*.desktop 2>/dev/null && echo
 
+ls -l -G -h --color=always $HOME/.local/share/applications/zeroinstall-dispcalgui.desktop 2>/dev/null && echo
+
 ls -l -G -h --color=always --group-directories-first -R $HOME/.local/share/man/man1/dispcalGUI* 2>/dev/null && echo
 
 ls -l -G -h --color=always --group-directories-first -R $HOME/.local/share/pyshared/dispcalGUI 2>/dev/null && echo
@@ -62,6 +64,8 @@ ls -l -G -h --color=always --group-directories-first -R /usr/local/lib*/python*/
 
 ls -l -G -h --color=always /usr/local/share/applications/dispcalGUI*.desktop 2>/dev/null && echo
 
+ls -l -G -h --color=always /usr/local/share/applications/zeroinstall-dispcalgui.desktop 2>/dev/null && echo
+
 ls -l -G -h --color=always --group-directories-first -R /usr/local/share/man/man1/dispcalGUI* 2>/dev/null && echo
 
 ls -l -G -h --color=always --group-directories-first -R /usr/local/share/pyshared/dispcalGUI 2>/dev/null && echo
@@ -90,6 +94,8 @@ ls -l -G -h --color=always --group-directories-first -R /usr/lib*/python*/*-pack
 
 ls -l -G -h --color=always /usr/share/applications/dispcalGUI*.desktop 2>/dev/null && echo
 
+ls -l -G -h --color=always /usr/share/applications/zeroinstall-dispcalgui 2>/dev/null && echo
+
 ls -l -G -h --color=always --group-directories-first -R /usr/share/man/man1/dispcalGUI* 2>/dev/null && echo
 
 ls -l -G -h --color=always --group-directories-first -R /usr/share/pyshared/dispcalGUI 2>/dev/null && echo
