@@ -32,7 +32,7 @@ def update_preset(name):
 	t_a2b = {"t": colormath.CIEDCCT2XYZ, "T": colormath.planckianCT2XYZ}
 	trc = None
 	for option in options_dispcal:
-		if option[0] == "g":
+		if option[0] in ("g", "G"):
 			trc = trc_a2b.get(option[1:])
 			if not trc:
 				try:
@@ -41,20 +41,17 @@ def update_preset(name):
 					trc = False
 					print "Invalid dispcal -g parameter:", option[1:]
 			if trc:
-				print "dispcal -g parameter:", option[1:]
+				print "dispcal -%s parameter:" % option[0], option[1:]
 				print "Updating tone response curves..."
 				for chan in ("r", "g", "b"):
 					prof.tags["%sTRC" % chan].set_trc(trc, 256)
 				print "Transfer function:", prof.tags["%sTRC" % chan].get_transfer_function()[0][0]
-		elif option[0] in ("t", "T"):
+		elif option[0] in ("t", "T") and option[1:]:
 			print "dispcal -t parameter:", option[1:]
 			print "Updating white point..."
-			t = colormath.XYZ2CCT(prof.tags.wtpt.X,
-								  prof.tags.wtpt.Y,
-								  prof.tags.wtpt.Z)
 			(prof.tags.wtpt.X,
 			 prof.tags.wtpt.Y,
-			 prof.tags.wtpt.Z) = t_a2b[option[0]](float(option[1:] or t))
+			 prof.tags.wtpt.Z) = t_a2b[option[0]](float(option[1:]))
 		elif option[0] == "w":
 			print "dispcal -w parameter:", option[1:]
 			x, y = [float(v) for v in option[1:].split(",")]
@@ -62,6 +59,10 @@ def update_preset(name):
 			(prof.tags.wtpt.X,
 			 prof.tags.wtpt.Y,
 			 prof.tags.wtpt.Z) = colormath.xyY2XYZ(x, y)
+	for option in options_colprof:
+		if option[0] == "M":
+			print "Updating device model description..."
+			prof.setDeviceModelDescription(option[2:].strip('"'))
 	if "CIED" in prof.tags:
 		print "Removing 'CIED'..."
 		del prof.tags["CIED"]
